@@ -136,6 +136,9 @@ int k8s_worker_image = 0;
 // Disable the check for invalid use of AFS with HTCondor.
 static int disable_afs_check = 0;
 
+// A pretend port number to unqiuely identify the factory in catalog updates.
+static int pretend_port = 0;
+
 /*
 In a signal handler, only a limited number of functions are safe to
 invoke, so we construct a string and emit it with a low-level write.
@@ -676,6 +679,8 @@ struct jx *factory_to_jx(struct list *managers, struct list *foremen, int submit
 	struct jx *j= jx_object(NULL);
 	jx_insert_string(j, "type", "wq_factory");
 
+	jx_insert_integer(j, "port", pretend_port);
+
 	if(using_catalog) {
 		jx_insert_string(j, "project_regex",    project_regex);
 		jx_insert_string(j, "submission_regex", submission_regex);
@@ -1539,6 +1544,12 @@ int main(int argc, char *argv[])
 		using_catalog = 1;
 	}
 
+	/* When reporting to the catalog server, the factory is uniquely identified by name:address:port */
+	/* Since it does not have a real "port", choose a negative value. */
+
+	srand( time(0) + getpid() );
+	pretend_port = -(rand()%65536);
+
 	cctools_version_debug(D_DEBUG, argv[0]);
 
 	if(batch_queue_type == BATCH_QUEUE_TYPE_UNKNOWN) {
