@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2016- The University of Notre Dame
+Copyright (C) 2022 The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -14,7 +14,7 @@ See the file COPYING for details.
 #include <string.h>
 
 struct box_count {
-	int   count;
+	int count;
 	void *data;
 };
 
@@ -22,78 +22,74 @@ struct histogram {
 	struct itable *buckets;
 	double bucket_size;
 
-	int    total_count;
+	int total_count;
 	double max_value;
 	double min_value;
 	double mode;
 };
 
-struct histogram *histogram_create(double bucket_size) {
+struct histogram *histogram_create(double bucket_size)
+{
 
-	if(bucket_size <= 0) {
+	if (bucket_size <= 0) {
 		fatal("Bucket size should be larger than zero: %lf", bucket_size);
 	}
 
 	struct histogram *h = calloc(1, sizeof(struct histogram));
 
 	h->bucket_size = bucket_size;
-	h->buckets     = itable_create(0);
+	h->buckets = itable_create(0);
 
 	h->total_count = 0;
-	h->max_value   = 0;
-	h->min_value   = 0;
-	h->mode        = 0;
+	h->max_value = 0;
+	h->min_value = 0;
+	h->mode = 0;
 
 	return h;
 }
 
-void histogram_clear(struct histogram *h) {
-
-	uint64_t key;
-	struct box_count *box;
-
-	itable_firstkey(h->buckets);
-	while(itable_nextkey(h->buckets, &key, (void **) &box)) {
-		free(box);
-	}
+void histogram_clear(struct histogram *h)
+{
+	itable_clear(h->buckets, free);
 
 	h->total_count = 0;
-	h->max_value   = 0;
-	h->min_value   = 0;
-	h->mode        = 0;
-
-	itable_clear(h->buckets);
+	h->max_value = 0;
+	h->min_value = 0;
+	h->mode = 0;
 }
 
-void histogram_delete(struct histogram *h) {
+void histogram_delete(struct histogram *h)
+{
 	histogram_clear(h);
 
-	if(h->buckets) {
+	if (h->buckets) {
 		itable_delete(h->buckets);
 	}
 
 	free(h);
 }
 
-int histogram_size(struct histogram *h) {
+int histogram_size(struct histogram *h)
+{
 	int count = 0;
 
-	if(h->buckets) {
+	if (h->buckets) {
 		count += itable_size(h->buckets);
 	}
 
 	return count;
 }
 
-double histogram_bucket_size(struct histogram *h) {
+double histogram_bucket_size(struct histogram *h)
+{
 	return h->bucket_size;
 }
 
-
 /* buckets are: (start, end], with end as the key. */
-uint64_t bucket_of(struct histogram *h, double value) {
+uint64_t bucket_of(struct histogram *h, double value)
+{
 
-	uint64_t b = fabs(ceil(value/h->bucket_size));
+	uint64_t b = fabs(ceil(value / h->bucket_size));
 
 	/*
 	 * times 2 so that we can intercalate negative and positive values. itable
@@ -106,7 +102,7 @@ uint64_t bucket_of(struct histogram *h, double value) {
 	 * note this takes care of itable not liking the zero key, as 0 goes to 1.
 	 * */
 
-	if(value >= 0) {
+	if (value >= 0) {
 		b++;
 	}
 
@@ -114,26 +110,34 @@ uint64_t bucket_of(struct histogram *h, double value) {
 }
 
 /* return the largest value that would fall inside the bucket id */
-double end_of(struct histogram *h, uint64_t b) {
+double end_of(struct histogram *h, uint64_t b)
+{
 
 	/* even b's correspond to negative values */
 	int is_negative = (b % 2 == 0);
 
 	double start;
-	if(is_negative) {
-		start = (b/2)*(-1*h->bucket_size);
+	if (is_negative) {
+		start = (b / 2) * (-1 * h->bucket_size);
 	} else {
-		start = ((b-1)/2)*h->bucket_size;
+		start = ((b - 1) / 2) * h->bucket_size;
 	}
 
 	return start;
 }
 
-int histogram_insert(struct histogram *h, double value) {
+/* return the largest value of the bucket that test_value would fall in*/
+double histogram_round_up(struct histogram *h, double test_value)
+{
+	return end_of(h, bucket_of(h, test_value));
+}
+
+int histogram_insert(struct histogram *h, double value)
+{
 	uint64_t bucket = bucket_of(h, value);
 
 	struct box_count *box = itable_lookup(h->buckets, bucket);
-	if(!box) {
+	if (!box) {
 		box = calloc(1, sizeof(*box));
 		itable_insert(h->buckets, bucket, box);
 	}
@@ -143,53 +147,56 @@ int histogram_insert(struct histogram *h, double value) {
 
 	int mode_count = histogram_count(h, histogram_mode(h));
 
-	if(value > h->max_value || h->total_count < 1) {
+	if (value > h->max_value || h->total_count < 1) {
 		h->max_value = value;
 	}
 
-	if(value < h->min_value || h->total_count < 1) {
+	if (value < h->min_value || h->total_count < 1) {
 		h->min_value = value;
 	}
 
-	if(box->count > mode_count) {
-		h->mode       = end_of(h, bucket);
+	if (box->count > mode_count) {
+		h->mode = end_of(h, bucket);
 	}
 
 	return box->count;
 }
 
-int histogram_count(struct histogram *h, double value) {
+int histogram_count(struct histogram *h, double value)
+{
 	uint64_t bucket = bucket_of(h, value);
 
 	struct box_count *box = itable_lookup(h->buckets, bucket);
 
-	if(!box) {
+	if (!box) {
 		return 0;
 	}
 
 	return box->count;
 }
 
-int cmp_double(const void *va, const void *vb) {
-	double a = *((double *) va);
-	double b = *((double *) vb);
+int cmp_double(const void *va, const void *vb)
+{
+	double a = *((double *)va);
+	double b = *((double *)vb);
 
-	if(a < b) {
+	if (a < b) {
 		return -1;
 	}
 
-	if(a > b) {
+	if (a > b) {
 		return 1;
 	}
 
 	return 0;
 }
 
-double *histogram_buckets(struct histogram *h) {
+double *histogram_buckets(struct histogram *h)
+{
 
 	int n = histogram_size(h);
 
-	if(n < 1) {
+	if (n < 1) {
 		return NULL;
 	}
 
@@ -200,7 +207,7 @@ double *histogram_buckets(struct histogram *h) {
 	struct box_count *box;
 
 	itable_firstkey(h->buckets);
-	while(itable_nextkey(h->buckets, &key, (void **) &box)) {
+	while (itable_nextkey(h->buckets, &key, (void **)&box)) {
 		values[i] = end_of(h, key);
 		i++;
 	}
@@ -210,21 +217,23 @@ double *histogram_buckets(struct histogram *h) {
 	return values;
 }
 
-void histogram_set_bucket(struct histogram *h, double value, int count) {
+void histogram_set_bucket(struct histogram *h, double value, int count)
+{
 	uint64_t bucket = bucket_of(h, value);
 
 	struct box_count *box = itable_lookup(h->buckets, bucket);
-	if(!box) {
+	if (!box) {
 		box = calloc(1, sizeof(*box));
 		itable_insert(h->buckets, bucket, box);
 	}
 }
 
-void histogram_attach_data(struct histogram *h, double value, void *data) {
+void histogram_attach_data(struct histogram *h, double value, void *data)
+{
 	uint64_t bucket = bucket_of(h, value);
 
 	struct box_count *box = itable_lookup(h->buckets, bucket);
-	if(!box) {
+	if (!box) {
 		box = calloc(1, sizeof(*box));
 		itable_insert(h->buckets, bucket, box);
 	}
@@ -232,30 +241,34 @@ void histogram_attach_data(struct histogram *h, double value, void *data) {
 	box->data = data;
 }
 
-void *histogram_get_data(struct histogram *h, double value) {
+void *histogram_get_data(struct histogram *h, double value)
+{
 	uint64_t bucket = bucket_of(h, value);
 
 	struct box_count *box = itable_lookup(h->buckets, bucket);
-	if(!box) {
+	if (!box) {
 		return NULL;
 	}
 
 	return box->data;
 }
 
-int histogram_total_count(struct histogram *h) {
+int histogram_total_count(struct histogram *h)
+{
 	return h->total_count;
 }
 
-double histogram_max_value(struct histogram *h) {
+double histogram_max_value(struct histogram *h)
+{
 	return h->max_value;
 }
 
-
-double histogram_min_value(struct histogram *h) {
+double histogram_min_value(struct histogram *h)
+{
 	return h->min_value;
 }
 
-double histogram_mode(struct histogram *h) {
+double histogram_mode(struct histogram *h)
+{
 	return h->mode;
 }
