@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2008- The University of Notre Dame
+Copyright (C) 2022 The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -10,19 +10,19 @@ See the file COPYING for details.
 
 #include <unistd.h>
 
-int host_memory_info_get(UINT64_T * avail, UINT64_T * total)
+int host_memory_info_get(UINT64_T *avail, UINT64_T *total)
 {
-	*total = getpagesize() * (UINT64_T) sysconf(_SC_PHYS_PAGES);
-	*avail = getpagesize() * (UINT64_T) sysconf(_SC_AVPHYS_PAGES);
+	*total = getpagesize() * (UINT64_T)sysconf(_SC_PHYS_PAGES);
+	*avail = getpagesize() * (UINT64_T)sysconf(_SC_AVPHYS_PAGES);
 	return 1;
 }
 
-#elif defined(CCTOOLS_OPSYS_DARWIN)
+#elif defined(CCTOOLS_OPSYS_DARWIN) || defined(CCTOOLS_OPSYS_FREEBSD)
 
-#include <sys/types.h>
 #include <sys/sysctl.h>
+#include <sys/types.h>
 
-int host_memory_info_get(UINT64_T * avail, UINT64_T * total)
+int host_memory_info_get(UINT64_T *avail, UINT64_T *total)
 {
 	unsigned x = 0;
 	size_t s = sizeof(x);
@@ -33,7 +33,7 @@ int host_memory_info_get(UINT64_T * avail, UINT64_T * total)
 
 #else
 
-int host_memory_info_get(UINT64_T * avail, UINT64_T * total)
+int host_memory_info_get(UINT64_T *avail, UINT64_T *total)
 {
 	*total = 0;
 	*avail = 0;
@@ -42,11 +42,11 @@ int host_memory_info_get(UINT64_T * avail, UINT64_T * total)
 
 #endif
 
-#include <sys/resource.h>
 #include <stdio.h>
+#include <sys/resource.h>
 #include <unistd.h>
 
-int host_memory_usage_get(UINT64_T * rssp, UINT64_T * totalp)
+int host_memory_usage_get(UINT64_T *rssp, UINT64_T *totalp)
 {
 #ifdef CCTOOLS_OPSYS_LINUX
 	/*
@@ -57,23 +57,23 @@ int host_memory_usage_get(UINT64_T * rssp, UINT64_T * totalp)
 	unsigned long total, rss, shared, text, libs, data, dirty;
 
 	FILE *file = fopen("/proc/self/statm", "r");
-	if(!file)
+	if (!file)
 		return 0;
 
 	fscanf(file, "%lu %lu %lu %lu %lu %lu %lu", &total, &rss, &shared, &text, &libs, &data, &dirty);
 
 	fclose(file);
 
-	*rssp = (UINT64_T) rss *getpagesize();
-	*totalp = (UINT64_T) total *getpagesize();
+	*rssp = (UINT64_T)rss * getpagesize();
+	*totalp = (UINT64_T)total * getpagesize();
 
 	return 1;
 #else
 	struct rusage ru;
 	int result = getrusage(RUSAGE_SELF, &ru);
-	if(result >= 0) {
-		*rssp = (UINT64_T) ru.ru_ixrss * getpagesize();
-		*totalp = (UINT64_T) ru.ru_ixrss * getpagesize();
+	if (result >= 0) {
+		*rssp = (UINT64_T)ru.ru_ixrss * getpagesize();
+		*totalp = (UINT64_T)ru.ru_ixrss * getpagesize();
 		return 1;
 	} else {
 		return 0;
@@ -81,4 +81,4 @@ int host_memory_usage_get(UINT64_T * rssp, UINT64_T * totalp)
 #endif
 }
 
-/* vim: set noexpandtab tabstop=4: */
+/* vim: set noexpandtab tabstop=8: */
