@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2015- The University of Notre Dame
+Copyright (C) 2022 The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -37,6 +37,7 @@ Will create the following output:
 */
 
 #include <stdint.h>
+#include <inttypes.h>
 
 /** JX atomic type.  */
 typedef enum {
@@ -53,6 +54,7 @@ typedef enum {
 } jx_type_t;
 
 typedef int64_t jx_int_t;
+#define PRIiJX PRIi64
 
 struct jx_comprehension {
 	unsigned line;
@@ -74,9 +76,10 @@ struct jx_item {
 /** JX key-value pairs used by @ref JX_OBJECT and @ref jx.pairs */
 
 struct jx_pair {
+	unsigned line;
 	struct jx      *key;	/**< key of this pair */
 	struct jx      *value;  /**< value of this pair */
-	unsigned line;
+	struct jx_comprehension *comp;
 	struct jx_pair *next;   /**< pointer to next pair */
 };
 
@@ -98,6 +101,7 @@ typedef enum {
 	JX_OP_LOOKUP,
 	JX_OP_CALL,
 	JX_OP_SLICE,
+	JX_OP_DOT,
 	JX_OP_INVALID,
 } jx_operator_t;
 
@@ -147,11 +151,17 @@ struct jx * jx_string_nocopy( char *string_value );
 /** Create a JX string value using prinf style formatting.  @param fmt A printf-style format string, followed by matching arguments.  @return A JX string value. */
 struct jx * jx_format( const char *fmt, ... );
 
-/** Create a JX symbol. Note that symbols are an extension to the JSON standard. A symbol is a reference to an external variable, which can be resolved by using @ref jx_eval. @param symbol_name A C string. @return A JX expression.
+/** Create a JX symbol.
+Note that symbols are an extension to the JSON standard. A symbol is a reference to an external variable, which can be resolved by using @ref jx_eval
+@param symbol_name A C string.
+@return A JX expression.
 */
 struct jx * jx_symbol( const char *symbol_name );
 
-/** Create a JX_ERROR. @param err The associated data for the error. This should be a string description of the error. @return A JX error value. */
+/** Create a JX_ERROR.
+@param err The associated data for the error. This should be a string description of the error.
+@return A JX error value.
+*/
 struct jx * jx_error( struct jx *err );
 
 /** Create a JX array.  @param items A linked list of @ref jx_item values.  @return A JX array. */
@@ -163,6 +173,18 @@ struct jx * jx_arrayv( struct jx *value, ... );
 /** Create a JX object.  @param pairs A linked list of @ref jx_pair key-value pairs.  @return a JX object. */
 struct jx * jx_object( struct jx_pair *pairs );
 
+/** Create a JX object. Arguments are alternating string key -- *jx values. Must be termianted with a null value.
+ * This is syntactic sugar for jx_object(jx_pair(jx_string(k), v, jx_pair(jx_string(k), v, jx_pair( etc.))));
+ *
+ * struct jx *j = jx_objectv("A", jx_integer(42),                  // key and value of A,
+ *                           "B", jx_objectv("C", jx_string("xyz") // key and value of B
+ *                           NULL));                               // terminating null value.
+ * @param key Name of the first property
+ * @param value Value for the first property
+ * @param ...  Alternating key-value pairs
+ * @return a JX object*/
+struct jx * jx_objectv( const char *key, struct jx *value, ... );
+
 /** Create a JX binary expression, @param oper The kind of operator.  @param left The left side of the expression.  @param right The right side of the expression. */
 struct jx * jx_operator( jx_operator_t oper, struct jx *left, struct jx *right );
 
@@ -190,6 +212,9 @@ int jx_isatomic( struct jx *j );
 /** Test an expression for the boolean value TRUE.  @param j An expression to test.  @return True if the expression is boolean and true. */
 int jx_istrue( struct jx *j );
 
+/** Test an expression for the boolean value FALSE @param j An expression to test.  @return True if the expression is boolean and false. */
+int jx_isfalse( struct jx *j );
+
 int jx_comprehension_equals(struct jx_comprehension *j, struct jx_comprehension *k);
 int jx_item_equals(struct jx_item *j, struct jx_item *k);
 int jx_pair_equals(struct jx_pair *j, struct jx_pair *k);
@@ -218,7 +243,7 @@ void jx_pair_delete( struct jx_pair *p );
 /** Delete an array item.  @param i The array item to delete. */
 void jx_item_delete( struct jx_item *i );
 
-/** Delete a comprehension. @param c The comprehension to delete. */
+/** Delete a comprehension. @param comp The comprehension to delete. */
 void jx_comprehension_delete(struct jx_comprehension *comp);
 
 /** Remove a key-value pair from an object.  @param object The object.  @param key The key. @return The corresponding value, or null if it is not present. */
@@ -227,9 +252,12 @@ struct jx * jx_remove( struct jx *object, struct jx *key );
 /** Insert a key-value pair into an object.  @param object The object.  @param key The key.  @param value The value. @return True on success, false on failure.  Failure can only occur if the object is not a @ref JX_OBJECT. */
 int jx_insert( struct jx *object, struct jx *key, struct jx *value );
 
-/** Insert a key-value pair into an object, unless the value is an empty collection, in which case delete the key and value.  @param key The key.  @param value The value. @return 1 on success, -1 on empty value, 0 on failure.  Failure can only occur if the object is not a @ref JX_OBJECT. */
+/** Insert a key-value pair into an object, unless the value is an empty collection, in which case delete the key and value.  @param object The target object. @param key The key.  @param value The value. @return 1 on success, -1 on empty value, 0 on failure.  Failure can only occur if the object is not a @ref JX_OBJECT. */
 int jx_insert_unless_empty( struct jx *object, struct jx *key, struct jx *value );
 
+/** Insert a boolean value into an object @param object The object @param key The key represented as a C string  @param value The boolean value. */
+void jx_insert_boolean( struct jx *object, const char *key, int value );
+
 /** Insert an integer value into an object @param object The object @param key The key represented as a C string  @param value The integer value. */
 void jx_insert_integer( struct jx *object, const char *key, jx_int_t value );
 
@@ -245,9 +273,12 @@ struct jx * jx_lookup( struct jx *object, const char *key );
 /* Like @ref jx_lookup, but found is set to 1 when the key is found. Useful for when value is false. */
 struct jx * jx_lookup_guard( struct jx *j, const char *key, int *found );
 
-/** Search for a string item in an object.  The key is an ordinary string value.  @param object The object in which to search.  @param key The string key to match.  @return The C string value of the matching object, or null if it is not found, or is not a string. */
+/** Search for a string item in an object.  The key is an ordinary string value. @param object The object in which to search.  @param key The string key to match.  @return The C string value of the matching object, or null if it is not found, or is not a string. */
 const char * jx_lookup_string( struct jx *object, const char *key );
 
+/** Search for a string item in an object.  Behaves the same as jx_lookup_string, but returns a duplicated copy.  The result must be deallocated with free(). @param object The object in which to search.  @param key The string key to match.  @return The C string value of the matching object, or null if it is not found, or is not a string. */
+char * jx_lookup_string_dup( struct jx *object, const char *key );
+
 /** Search for an integer item in an object.  The key is an ordinary string value.  @param object The object in which to search.  @param key The string key to match.  @return The integer value of the matching object, or zero if it is not found, or is not an integer. */
 jx_int_t jx_lookup_integer( struct jx *object, const char *key );
 
@@ -264,7 +295,7 @@ void jx_array_insert( struct jx *array, struct jx *value );
 void jx_array_append( struct jx *array, struct jx *value );
 
 /** Get the nth item in an array.  @param array The array to search.  @param nth The index of the desired value. @return The nth element, or NULL if the index is out of bounds. */
-struct jx * jx_array_index( struct jx *j, int nth );
+struct jx * jx_array_index( struct jx *array, int nth );
 
 /** Concatenate the given arrays into a single array. The passed arrays are consumed. @param array An array to concatenate. The list of arrays must be terminated by NULL. */
 struct jx *jx_array_concat( struct jx *array, ...);
@@ -277,7 +308,7 @@ struct jx *jx_array_shift(struct jx *array);
 /** Determine if an expression is constant.  Traverses the expression recursively, and returns true if it consists only of constant values, arrays, and objects. @param j The expression to evaluate.  @return True if constant. */
 int jx_is_constant( struct jx *j );
 
-/** Export a jx object as a set of environment variables.  @param j A JX_OBJECT. */
+/** Export a jx object into the current environment using setenv(). @param j A JX_OBJECT. */
 void jx_export( struct jx *j );
 
 /** Iterate over the values in an array.
@@ -361,4 +392,4 @@ struct jx *jx_merge(struct jx *j, ...);
 
 #endif
 
-/*vim: set noexpandtab tabstop=4: */
+/*vim: set noexpandtab tabstop=8: */
