@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2016- The University of Notre Dame
+Copyright (C) 2022 The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -9,6 +9,9 @@ See the file COPYING for details.
 
 #include "jx.h"
 
+/** @file jx_eval.h Implements evaluation of JX expressions.
+*/
+
 /** Evaluate an expression.
 Traverses the expression, evaluates all operators and evalutes
 unbound symbols by looking for matches in the context object.
@@ -30,5 +33,13 @@ If the expression is invalid in some way, an object of type @ref JX_NULL is retu
 */
 struct jx * jx_eval_with_defines( struct jx *j, struct jx* context );
 
+/** Enable external functions.
+A small number of JX functions make use of "external" context,
+For safety, these functions are not enabled unless the user first
+calls jx_eval_enable_external(1).
+@param enable If non-zero, enable external functions, otherwise disable.
+*/
+
+void jx_eval_enable_external( int enable );
 
 #endif
