@@ -1,34 +1,77 @@
 /*
-Copyright (C) 2016- The University of Notre Dame
+Copyright (C) 2022 The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
 
 #include <assert.h>
-#include <math.h>
+#include <ctype.h>
+#include <dirent.h>
+#include <errno.h>
 #include <inttypes.h>
+#include <libgen.h>
+#include <math.h>
 #include <stdarg.h>
 #include <stdbool.h>
 #include <stdio.h>
 #include <string.h>
-#include <libgen.h>
 #include <sys/types.h>
-#include <dirent.h>
-#include <errno.h>
-#include <ctype.h>
 #include <unistd.h>
-#include <stdarg.h>
 
+#include "buffer.h"
 #include "jx.h"
 #include "jx_eval.h"
 #include "jx_match.h"
 #include "jx_parse.h"
 #include "jx_print.h"
+#include "jx_sub.h"
 #include "stringtools.h"
 #include "xxmalloc.h"
-#include "buffer.h"
 
-static struct jx *make_error(const char *funcname, struct jx *args, const char *fmt, ...) {
+#include "jx_function.h"
+
+typedef enum {
+	JX_DOUBLE_ARG = 1, // Function takes two arguments.
+	JX_DEFER_EVAL = 2, // Defer evaluation of second argument.
+	JX_EXTERNAL = 4	   // Function uses data external to context.
+} jx_function_flags;
+
+typedef union {
+	struct jx *(*single_arg)(struct jx *args);
+	struct jx *(*double_arg)(struct jx *args, struct jx *ctx);
+} jx_function_pointer;
+
+struct jx_function_info {
+	const char *name;
+	const char *help_text;
+	jx_function_flags flags;
+	jx_function_pointer function_pointer;
+};
+
+const struct jx_function_info jx_functions[] = {{"range", "range( start, stop, step )", 0, {.single_arg = jx_function_range}},
+		{"format", "format( str: %s int: %d float: %f\", \"hello\", 42, 3.14159 )", 0, {.single_arg = jx_function_format}},
+		{"join", "join( array, delim )", 0, {.single_arg = jx_function_join}},
+		{"ceil", "ceil( value )", 0, {.single_arg = jx_function_ceil}},
+		{"floor", "floor( value )", 0, {.single_arg = jx_function_floor}},
+		{"basename", "basename( path )", 0, {.single_arg = jx_function_basename}},
+		{"dirname", "dirname( path )", 0, {.single_arg = jx_function_dirname}},
+		{"listdir", "listdir( path )", JX_EXTERNAL, {.single_arg = jx_function_listdir}},
+		{"escape", "escape( string )", 0, {.single_arg = jx_function_escape}},
+		{"len", "len( array )", 0, {.single_arg = jx_function_len}},
+		{"fetch", "fetch( URL/path )", JX_EXTERNAL, {.single_arg = jx_function_fetch}},
+		{"schema", "schema( object )", 0, {.single_arg = jx_function_schema}},
+		{"like", "like( object, string )", 0, {.single_arg = jx_function_like}},
+		{"keys", "keys( object )", 0, {.single_arg = jx_function_keys}},
+		{"values", "values( object )", 0, {.single_arg = jx_function_values}},
+		{"items", "items( object )", 0, {.single_arg = jx_function_items}},
+		{"template", "template( string [,object] )", JX_DOUBLE_ARG, {.double_arg = jx_function_template}},
+		{"select", "select( array, boolean )", JX_DOUBLE_ARG | JX_DEFER_EVAL, {.double_arg = jx_function_select}},
+		{"where", "where( array, boolean )", JX_DOUBLE_ARG | JX_DEFER_EVAL, {.double_arg = jx_function_select}},
+		{"project", "project( array, expression )", JX_DOUBLE_ARG | JX_DEFER_EVAL, {.double_arg = jx_function_project}},
+		{0, 0, 0, {0}}};
+
+static struct jx *make_error(const char *funcname, struct jx *args, const char *fmt, ...)
+{
 	assert(funcname);
 	assert(args);
 	assert(fmt);
@@ -48,55 +91,135 @@ static struct jx *make_error(const char *funcname, struct jx *args, const char *
 	return err;
 }
 
-static char *jx_function_format_value(char spec, struct jx *args) {
-	if (spec == '%') return xxstrdup("%");
+extern int __jx_eval_external_functions_flag;
+
+struct jx *jx_function_eval(const char *funcname, struct jx *args, struct jx *ctx)
+{
+	int i = 0;
+	struct jx_function_info info;
+
+	while ((info = jx_functions[i++]).name != NULL) {
+		if (strcmp(info.name, funcname) != 0) {
+			continue;
+		}
+
+		if (info.flags & JX_EXTERNAL && !__jx_eval_external_functions_flag) {
+			return make_error(funcname, args, "external functions disabled");
+		}
+
+		struct jx *arg;
+		if (info.flags & JX_DEFER_EVAL) {
+			arg = jx_copy(args);
+		} else {
+			arg = jx_eval(args, ctx);
+		}
+
+		if (info.flags & JX_DOUBLE_ARG) {
+			return (*info.function_pointer.double_arg)(arg, ctx);
+		} else {
+			return (*info.function_pointer.single_arg)(arg);
+		}
+	}
+
+	return make_error(funcname, args, "invalid function name");
+}
+
+struct jx *jx_function_sub(const char *funcname, struct jx *args, struct jx *ctx)
+{
+	int i = 0;
+	struct jx_function_info info;
+
+	while ((info = jx_functions[i++]).name != NULL) {
+		if (strcmp(info.name, funcname) != 0) {
+			continue;
+		}
+
+		if (!(info.flags & JX_DEFER_EVAL)) {
+			return jx_sub(args, ctx);
+		} else {
+			// only sub objlist (ignoring select's boolean and project's expression)
+			struct jx *val = jx_array_index(args, 0);
+			struct jx *objlist = jx_array_index(args, 1);
+
+			struct jx *new_val = jx_copy(val);
+			struct jx *new_objlist = jx_sub(objlist, ctx);
+
+			// add back to args
+			struct jx *ret = jx_array(0);
+			jx_array_append(ret, new_val);
+			jx_array_append(ret, new_objlist);
+
+			return ret;
+		}
+	}
+
+	return make_error(funcname, args, "invalid function name");
+}
+
+void jx_function_help(FILE *file)
+{
+	int i = 0;
+	struct jx_function_info info;
+
+	fprintf(file, "\n");
+	while ((info = jx_functions[i++]).name != NULL) {
+		fprintf(file, "  %s\n", info.help_text);
+	}
+	fprintf(file, "\n");
+}
+
+static char *jx_function_format_value(char spec, struct jx *args)
+{
+	if (spec == '%')
+		return xxstrdup("%");
 	char *result = NULL;
 	struct jx *j = jx_array_shift(args);
 	switch (spec) {
-		case 'd':
-		case 'i':
-			if (jx_istype(j, JX_INTEGER))
-				result = string_format(
-					"%" PRIi64, j->u.integer_value);
-			break;
-		case 'e':
-			if (jx_istype(j, JX_DOUBLE))
-				result = string_format("%e", j->u.double_value);
-			break;
-		case 'E':
-			if (jx_istype(j, JX_DOUBLE))
-				result = string_format("%E", j->u.double_value);
-			break;
-		case 'f':
-			if (jx_istype(j, JX_DOUBLE))
-				result = string_format("%f", j->u.double_value);
-			break;
-		case 'F':
-			if (jx_istype(j, JX_DOUBLE))
-				result = string_format("%F", j->u.double_value);
-			break;
-		case 'g':
-			if (jx_istype(j, JX_DOUBLE))
-				result = string_format("%g", j->u.double_value);
-			break;
-		case 'G':
-			if (jx_istype(j, JX_DOUBLE))
-				result = string_format("%G", j->u.double_value);
-			break;
-		case 's':
-			if (jx_istype(j, JX_STRING))
-				result = xxstrdup(j->u.string_value);
-			break;
-		default:
-			break;
+	case 'd':
+	case 'i':
+		if (jx_istype(j, JX_INTEGER))
+			result = string_format("%" PRIi64, j->u.integer_value);
+		break;
+	case 'e':
+		if (jx_istype(j, JX_DOUBLE))
+			result = string_format("%e", j->u.double_value);
+		break;
+	case 'E':
+		if (jx_istype(j, JX_DOUBLE))
+			result = string_format("%E", j->u.double_value);
+		break;
+	case 'f':
+		if (jx_istype(j, JX_DOUBLE))
+			result = string_format("%f", j->u.double_value);
+		break;
+	case 'F':
+		if (jx_istype(j, JX_DOUBLE))
+			result = string_format("%F", j->u.double_value);
+		break;
+	case 'g':
+		if (jx_istype(j, JX_DOUBLE))
+			result = string_format("%g", j->u.double_value);
+		break;
+	case 'G':
+		if (jx_istype(j, JX_DOUBLE))
+			result = string_format("%G", j->u.double_value);
+		break;
+	case 's':
+		if (jx_istype(j, JX_STRING))
+			result = xxstrdup(j->u.string_value);
+		break;
+	default:
+		break;
 	}
 	jx_delete(j);
 	return result;
 }
 
-struct jx *jx_function_format(struct jx *args) {
+struct jx *jx_function_format(struct jx *args)
+{
 	assert(args);
-	if (jx_istype(args, JX_ERROR)) return args;
+	if (jx_istype(args, JX_ERROR))
+		return args;
 	const char *func = "format";
 	char *format = NULL;
 	char *result = xxstrdup("");
@@ -146,25 +269,30 @@ FAILURE:
 }
 
 // see https://docs.python.org/2/library/functions.html#range
-struct jx *jx_function_range(struct jx *args) {
+struct jx *jx_function_range(struct jx *args)
+{
 	assert(args);
-	if (jx_istype(args, JX_ERROR)) return args;
+	if (jx_istype(args, JX_ERROR))
+		return args;
 	const char *func = "range";
 	jx_int_t start, stop, step;
 	struct jx *result = NULL;
 
 	assert(args);
 	switch (jx_match_array(args, &start, JX_INTEGER, &stop, JX_INTEGER, &step, JX_INTEGER, NULL)) {
-		case 1:
-			stop = start;
-			start = 0;
-			step = 1;
-			break;
-		case 2: step = 1; break;
-		case 3: break;
-		default:
-			result = make_error(func, args, "invalid arguments");
-			goto FAILURE;
+	case 1:
+		stop = start;
+		start = 0;
+		step = 1;
+		break;
+	case 2:
+		step = 1;
+		break;
+	case 3:
+		break;
+	default:
+		result = make_error(func, args, "invalid arguments");
+		goto FAILURE;
 	}
 
 	if (step == 0) {
@@ -188,51 +316,53 @@ FAILURE:
 	return result;
 }
 
-
-struct jx *jx_function_join(struct jx *args) {
+struct jx *jx_function_join(struct jx *args)
+{
 	assert(args);
-	if (jx_istype(args, JX_ERROR)) return args;
+	if (jx_istype(args, JX_ERROR))
+		return args;
 	const char *func = "join";
 	char *result = NULL;
 	struct jx *j = NULL;
 
 	struct jx *list = NULL;
-	struct jx *delimeter= NULL;	
+	struct jx *delimeter = NULL;
 
 	int length = jx_array_length(args);
-	if(length>2){
+	if (length > 2) {
 		j = make_error(func, args, "too many arguments to join");
 		goto FAILURE;
-	}
-	else if(length<=0){
+	} else if (length <= 0) {
 		j = make_error(func, args, "too few arguments to join");
 		goto FAILURE;
 	}
-	
+
 	list = jx_array_shift(args);
-	if (!jx_istype(list, JX_ARRAY)){
+	if (!jx_istype(list, JX_ARRAY)) {
 		j = make_error(func, args, "A list must be the first argument in join");
 		goto FAILURE;
 	}
-	
-	if (length==2){
-		delimeter  = jx_array_shift(args);
-		if(!jx_istype(delimeter, JX_STRING)){
+
+	if (length == 2) {
+		delimeter = jx_array_shift(args);
+		if (!jx_istype(delimeter, JX_STRING)) {
 			j = make_error(func, args, "A delimeter must be defined as a string");
 			goto FAILURE;
 		}
 	}
-	
-	result=xxstrdup("");	
-	struct jx *value=NULL;
-	for (size_t location = 0; (value = jx_array_shift(list)); location++){
-		if (!jx_istype(value, JX_STRING)){
+
+	result = xxstrdup("");
+	struct jx *value = NULL;
+	for (size_t location = 0; (value = jx_array_shift(list)); location++) {
+		if (!jx_istype(value, JX_STRING)) {
 			j = make_error(func, args, "All array values must be strings");
 			goto FAILURE;
 		}
-		if(location > 0){	
-			if(delimeter) result = string_combine(result, delimeter->u.string_value);
-			else result = string_combine(result, " ");
+		if (location > 0) {
+			if (delimeter)
+				result = string_combine(result, delimeter->u.string_value);
+			else
+				result = string_combine(result, " ");
 		}
 		result = string_combine(result, value->u.string_value);
 		jx_delete(value);
@@ -247,18 +377,20 @@ FAILURE:
 	return j;
 }
 
-struct jx *jx_function_ceil(struct jx *args) {
+struct jx *jx_function_ceil(struct jx *args)
+{
 	assert(args);
-	if (jx_istype(args, JX_ERROR)) return args;
+	if (jx_istype(args, JX_ERROR))
+		return args;
 	const char *func = "ceil";
 	struct jx *result = NULL;
 	struct jx *val = NULL;
 
 	int length = jx_array_length(args);
-	if(length>1){
+	if (length > 1) {
 		result = make_error(func, args, "too many arguments");
 		goto FAILURE;
-	} else if(length<=0){
+	} else if (length <= 0) {
 		result = make_error(func, args, "too few arguments");
 		goto FAILURE;
 	}
@@ -266,16 +398,16 @@ struct jx *jx_function_ceil(struct jx *args) {
 	val = jx_array_shift(args);
 
 	switch (val->type) {
-		case JX_DOUBLE:
-			result = jx_double(ceil(val->u.double_value));
-			break;
-		case JX_INTEGER:
-			result = jx_integer(ceil(val->u.integer_value));
-			break;
-		default:
-			result = make_error(func, args, "arg of invalid type");
-			goto FAILURE;
-	}	
+	case JX_DOUBLE:
+		result = jx_double(ceil(val->u.double_value));
+		break;
+	case JX_INTEGER:
+		result = jx_integer(ceil(val->u.integer_value));
+		break;
+	default:
+		result = make_error(func, args, "arg of invalid type");
+		goto FAILURE;
+	}
 
 FAILURE:
 	jx_delete(args);
@@ -283,18 +415,20 @@ FAILURE:
 	return result;
 }
 
-struct jx *jx_function_floor(struct jx *args) {
+struct jx *jx_function_floor(struct jx *args)
+{
 	assert(args);
-	if (jx_istype(args, JX_ERROR)) return args;
+	if (jx_istype(args, JX_ERROR))
+		return args;
 	const char *func = "floor";
-	struct jx *result = NULL;	
+	struct jx *result = NULL;
 	struct jx *val = NULL;
 
 	int length = jx_array_length(args);
-	if(length>1){
+	if (length > 1) {
 		result = make_error(func, args, "too many arguments");
 		goto FAILURE;
-	} else if(length<=0){
+	} else if (length <= 0) {
 		result = make_error(func, args, "too few arguments");
 		goto FAILURE;
 	}
@@ -302,16 +436,16 @@ struct jx *jx_function_floor(struct jx *args) {
 	val = jx_array_shift(args);
 
 	switch (val->type) {
-		case JX_DOUBLE:
-			result = jx_double(floor(val->u.double_value));
-			break;
-		case JX_INTEGER:
-			result = jx_integer(floor(val->u.integer_value));
-			break;
-		default:
-			result = make_error(func, args, "arg of invalid type");
-			goto FAILURE;
-	}	
+	case JX_DOUBLE:
+		result = jx_double(floor(val->u.double_value));
+		break;
+	case JX_INTEGER:
+		result = jx_integer(floor(val->u.integer_value));
+		break;
+	default:
+		result = make_error(func, args, "arg of invalid type");
+		goto FAILURE;
+	}
 
 FAILURE:
 	jx_delete(args);
@@ -319,19 +453,20 @@ FAILURE:
 	return result;
 }
 
-
-struct jx *jx_function_basename(struct jx *args) {
+struct jx *jx_function_basename(struct jx *args)
+{
 	assert(args);
-	if (jx_istype(args, JX_ERROR)) return args;
+	if (jx_istype(args, JX_ERROR))
+		return args;
 	const char *func = "basename";
 	struct jx *result = NULL;
 
 	int length = jx_array_length(args);
-	if (length < 1){
+	if (length < 1) {
 		result = make_error(func, args, "one argument is required");
 		goto FAILURE;
 	}
-	if (length > 2){
+	if (length > 2) {
 		result = make_error(func, args, "only two arguments are allowed");
 		goto FAILURE;
 	}
@@ -364,14 +499,16 @@ FAILURE:
 	return result;
 }
 
-struct jx *jx_function_dirname(struct jx *args) {
+struct jx *jx_function_dirname(struct jx *args)
+{
 	assert(args);
-	if (jx_istype(args, JX_ERROR)) return args;
+	if (jx_istype(args, JX_ERROR))
+		return args;
 	const char *func = "dirname";
 	struct jx *result = NULL;
 
 	int length = jx_array_length(args);
-	if (length != 1){
+	if (length != 1) {
 		result = make_error(func, args, "dirname takes one argument");
 		goto FAILURE;
 	}
@@ -392,9 +529,11 @@ FAILURE:
 	return result;
 }
 
-struct jx *jx_function_listdir(struct jx *args) {
+struct jx *jx_function_listdir(struct jx *args)
+{
 	assert(args);
-	if (jx_istype(args, JX_ERROR)) return args;
+	if (jx_istype(args, JX_ERROR))
+		return args;
 	const char *func = "listdir";
 	struct jx *out = NULL;
 
@@ -414,16 +553,16 @@ struct jx *jx_function_listdir(struct jx *args) {
 
 	DIR *d = opendir(a->u.string_value);
 	if (!d) {
-		out = make_error(func, args, "%s, %s",
-			a->u.string_value,
-			strerror(errno));
+		out = make_error(func, args, "%s, %s", a->u.string_value, strerror(errno));
 		goto FAILURE;
 	}
 
 	out = jx_array(NULL);
 	for (struct dirent *e; (e = readdir(d));) {
-		if (!strcmp(".", e->d_name)) continue;
-		if (!strcmp("..", e->d_name)) continue;
+		if (!strcmp(".", e->d_name))
+			continue;
+		if (!strcmp("..", e->d_name))
+			continue;
 		jx_array_append(out, jx_string(e->d_name));
 	}
 	closedir(d);
@@ -432,14 +571,16 @@ FAILURE:
 	return out;
 }
 
-struct jx *jx_function_escape(struct jx *args) {
+struct jx *jx_function_escape(struct jx *args)
+{
 	assert(args);
-	if (jx_istype(args, JX_ERROR)) return args;
+	if (jx_istype(args, JX_ERROR))
+		return args;
 	const char *func = "escape";
 	struct jx *result = NULL;
 
 	int length = jx_array_length(args);
-	if (length != 1){
+	if (length != 1) {
 		result = make_error(func, args, "escape takes one argument");
 		goto FAILURE;
 	}
@@ -460,7 +601,8 @@ FAILURE:
 	return result;
 }
 
-static struct jx *expand_template(struct jx *template, struct jx *ctx, struct jx *overrides) {
+static struct jx *expand_template(struct jx *template, struct jx *ctx, struct jx *overrides)
+{
 	const char *func = "template";
 
 	assert(template);
@@ -484,13 +626,13 @@ static struct jx *expand_template(struct jx *template, struct jx *ctx, struct jx
 			continue;
 		}
 		// quoted {
-		if (*s == '{' && *(s+1) == '{') {
+		if (*s == '{' && *(s + 1) == '{') {
 			buffer_putliteral(&buf, "{");
 			s += 2;
 			continue;
 		}
 		// quoted }
-		if (*s == '}' && *(s+1) == '}') {
+		if (*s == '}' && *(s + 1) == '}') {
 			buffer_putliteral(&buf, "}");
 			s += 2;
 			continue;
@@ -502,16 +644,15 @@ static struct jx *expand_template(struct jx *template, struct jx *ctx, struct jx
 			goto FAILURE;
 		}
 		s++;
-		while (isspace(*s)) s++; // eat leading whitespace
+		while (isspace(*s))
+			s++; // eat leading whitespace
 
 		if (*s == 0) {
-			out = make_error(func, template,
-				"unterminated template expression");
+			out = make_error(func, template, "unterminated template expression");
 			goto FAILURE;
 		}
 		if (!isalpha(*s) && *s != '_') {
-			out = make_error(func, template,
-				"invalid template; each expression must be a single identifier");
+			out = make_error(func, template, "invalid template; each expression must be a single identifier");
 			goto FAILURE;
 		}
 		buffer_putlstring(&var, s, 1); // copy identifier to buffer
@@ -520,16 +661,15 @@ static struct jx *expand_template(struct jx *template, struct jx *ctx, struct jx
 			buffer_putlstring(&var, s, 1);
 			s++;
 		}
-		while (isspace(*s)) s++; // eat trailing whitespace
+		while (isspace(*s))
+			s++; // eat trailing whitespace
 
 		if (*s == 0) {
-			out = make_error(func, template,
-				"unterminated template expression");
+			out = make_error(func, template, "unterminated template expression");
 			goto FAILURE;
 		}
 		if (*s != '}') {
-			out = make_error(func, template,
-				"invalid template; each expression must be a single identifier");
+			out = make_error(func, template, "invalid template; each expression must be a single identifier");
 			goto FAILURE;
 		}
 		s++;
@@ -542,17 +682,16 @@ static struct jx *expand_template(struct jx *template, struct jx *ctx, struct jx
 			goto FAILURE;
 		}
 		switch (k->type) {
-			case JX_INTEGER:
-			case JX_DOUBLE:
-				jx_print_buffer(k, &buf);
-				break;
-			case JX_STRING:
-				buffer_putstring(&buf, k->u.string_value);
-				break;
-			default:
-				out = make_error(func, template,
-					"cannot format expression in template");
-				goto FAILURE;
+		case JX_INTEGER:
+		case JX_DOUBLE:
+			jx_print_buffer(k, &buf);
+			break;
+		case JX_STRING:
+			buffer_putstring(&buf, k->u.string_value);
+			break;
+		default:
+			out = make_error(func, template, "cannot format expression in template");
+			goto FAILURE;
 		}
 		buffer_rewind(&var, 0);
 	}
@@ -564,9 +703,11 @@ FAILURE:
 	return out;
 }
 
-struct jx *jx_function_template(struct jx *args, struct jx *ctx) {
+struct jx *jx_function_template(struct jx *args, struct jx *ctx)
+{
 	assert(args);
-	if (jx_istype(args, JX_ERROR)) return args;
+	if (jx_istype(args, JX_ERROR))
+		return args;
 	assert(jx_istype(args, JX_ARRAY));
 	assert(!ctx || jx_istype(ctx, JX_OBJECT));
 
@@ -602,15 +743,17 @@ FAILURE:
 	return out;
 }
 
-struct jx *jx_function_len(struct jx *args){
+struct jx *jx_function_len(struct jx *args)
+{
 	assert(args);
-	if (jx_istype(args, JX_ERROR)) return args;
+	if (jx_istype(args, JX_ERROR))
+		return args;
 	assert(jx_istype(args, JX_ARRAY));
 
 	const char *func = "len";
 	struct jx *out = NULL;
 
-	struct jx* item = jx_array_index(args, 0);
+	struct jx *item = jx_array_index(args, 0);
 	if (!jx_istype(item, JX_ARRAY)) {
 		out = make_error(func, args, "argument must be an array");
 		goto FAILURE;
@@ -622,12 +765,13 @@ struct jx *jx_function_len(struct jx *args){
 FAILURE:
 	jx_delete(args);
 	return out;
-
 }
 
-struct jx *jx_function_keys(struct jx *args){
+struct jx *jx_function_keys(struct jx *args)
+{
 	assert(args);
-	if (jx_istype(args, JX_ERROR)) return args;
+	if (jx_istype(args, JX_ERROR))
+		return args;
 	assert(jx_istype(args, JX_ARRAY));
 
 	const char *func = "keys";
@@ -638,7 +782,7 @@ struct jx *jx_function_keys(struct jx *args){
 		goto FAILURE;
 	}
 
-	struct jx* item = jx_array_index(args, 0);
+	struct jx *item = jx_array_index(args, 0);
 	if (!jx_istype(item, JX_OBJECT)) {
 		out = make_error(func, args, "argument must be an object");
 		goto FAILURE;
@@ -653,12 +797,13 @@ struct jx *jx_function_keys(struct jx *args){
 FAILURE:
 	jx_delete(args);
 	return out;
-
 }
 
-struct jx *jx_function_values(struct jx *args){
+struct jx *jx_function_values(struct jx *args)
+{
 	assert(args);
-	if (jx_istype(args, JX_ERROR)) return args;
+	if (jx_istype(args, JX_ERROR))
+		return args;
 	assert(jx_istype(args, JX_ARRAY));
 
 	const char *func = "keys";
@@ -669,7 +814,7 @@ struct jx *jx_function_values(struct jx *args){
 		goto FAILURE;
 	}
 
-	struct jx* item = jx_array_index(args, 0);
+	struct jx *item = jx_array_index(args, 0);
 	if (!jx_istype(item, JX_OBJECT)) {
 		out = make_error(func, args, "argument must be an object");
 		goto FAILURE;
@@ -684,12 +829,13 @@ struct jx *jx_function_values(struct jx *args){
 FAILURE:
 	jx_delete(args);
 	return out;
-
 }
 
-struct jx *jx_function_items(struct jx *args){
+struct jx *jx_function_items(struct jx *args)
+{
 	assert(args);
-	if (jx_istype(args, JX_ERROR)) return args;
+	if (jx_istype(args, JX_ERROR))
+		return args;
 	assert(jx_istype(args, JX_ARRAY));
 
 	const char *func = "keys";
@@ -700,7 +846,7 @@ struct jx *jx_function_items(struct jx *args){
 		goto FAILURE;
 	}
 
-	struct jx* item = jx_array_index(args, 0);
+	struct jx *item = jx_array_index(args, 0);
 	if (!jx_istype(item, JX_OBJECT)) {
 		out = make_error(func, args, "argument must be an object");
 		goto FAILURE;
@@ -719,23 +865,23 @@ struct jx *jx_function_items(struct jx *args){
 FAILURE:
 	jx_delete(args);
 	return out;
-
 }
 
-
-struct jx *jx_function_fetch(struct jx *args) {
+struct jx *jx_function_fetch(struct jx *args)
+{
 	assert(args);
-	if (jx_istype(args, JX_ERROR)) return args;
+	if (jx_istype(args, JX_ERROR))
+		return args;
 	const char *func = "fetch";
 
 	struct jx *result = NULL;
 	struct jx *val = NULL;
 
 	int length = jx_array_length(args);
-	if(length>1){
+	if (length > 1) {
 		result = make_error(func, args, "must pass in one path or one URL");
 		goto FAILURE;
-	} else if(length<=0){
+	} else if (length <= 0) {
 		result = make_error(func, args, "must pass in a path or URL");
 		goto FAILURE;
 	}
@@ -748,30 +894,28 @@ struct jx *jx_function_fetch(struct jx *args) {
 	}
 
 	const char *path = val->u.string_value;
-	if(string_match_regex(path, "http(s)?://")) {
-		//Arbitrary 30 second timeout to perform curl
+	if (string_match_regex(path, "http(s)?://")) {
+		// Arbitrary 30 second timeout to perform curl
 		char *cmd = string_format("curl -m 30 -s %s", path);
-		FILE *stream = popen(cmd,"r");
+		FILE *stream = popen(cmd, "r");
 		free(cmd);
-		if(!stream) {
-			result = make_error(func, args, "error fetching %s: %s",
-				path, strerror(errno));
+		if (!stream) {
+			result = make_error(func, args, "error fetching %s: %s", path, strerror(errno));
 			goto FAILURE;
 		}
 		result = jx_parse_stream(stream);
 		pclose(stream);
 	} else {
 		FILE *stream = fopen(path, "r");
-		if(!stream) {
-			result = make_error(func, args, "error reading %s: %s\n",
-				path, strerror(errno));
+		if (!stream) {
+			result = make_error(func, args, "error reading %s: %s\n", path, strerror(errno));
 			goto FAILURE;
 		}
 		result = jx_parse_stream(stream);
 		fclose(stream);
 	}
 
-	if(!result) {
+	if (!result) {
 		result = make_error(func, args, "error parsing JSON in %s", path);
 		goto FAILURE;
 	}
@@ -782,7 +926,8 @@ FAILURE:
 	return result;
 }
 
-struct jx *jx_function_select(struct jx *args, struct jx *ctx) {
+struct jx *jx_function_select(struct jx *args, struct jx *ctx)
+{
 	assert(args);
 	assert(jx_istype(args, JX_ARRAY));
 	assert(jx_istype(ctx, JX_OBJECT));
@@ -792,8 +937,8 @@ struct jx *jx_function_select(struct jx *args, struct jx *ctx) {
 	struct jx *new_ctx = NULL;
 	struct jx *j = NULL;
 
-	struct jx *val = jx_array_shift(args);
 	struct jx *objlist = jx_array_shift(args);
+	struct jx *val = jx_array_shift(args);
 	if (jx_array_length(args) != 0) {
 		result = make_error(func, args, "2 arguments required");
 		goto FAILURE;
@@ -816,7 +961,7 @@ struct jx *jx_function_select(struct jx *args, struct jx *ctx) {
 	result = jx_array(0);
 
 	struct jx *item;
-	for(void *i = NULL; (item = jx_iterate_array(objlist, &i));) {
+	for (void *i = NULL; (item = jx_iterate_array(objlist, &i));) {
 		if (!jx_istype(item, JX_OBJECT)) {
 			jx_delete(result);
 			result = make_error(func, args, "list of objects required");
@@ -832,11 +977,11 @@ struct jx *jx_function_select(struct jx *args, struct jx *ctx) {
 		}
 		if (!jx_istype(j, JX_BOOLEAN)) {
 			jx_delete(result);
-			result = make_error(func, args,
-				"select expression must use a boolean predicate");
+			result = make_error(func, args, "select expression must use a boolean predicate");
 			goto FAILURE;
 		}
-		if(j->u.boolean_value) jx_array_append(result, jx_copy(item));
+		if (j->u.boolean_value)
+			jx_array_append(result, jx_copy(item));
 		jx_delete(j);
 		jx_delete(new_ctx);
 		j = NULL;
@@ -852,18 +997,19 @@ FAILURE:
 	return result;
 }
 
-struct jx *jx_function_project(struct jx *args, struct jx *ctx) {
+struct jx *jx_function_project(struct jx *args, struct jx *ctx)
+{
 	assert(args);
 	assert(jx_istype(args, JX_ARRAY));
 	assert(jx_istype(ctx, JX_OBJECT));
 
 	const char *func = "project";
-	struct jx * result = NULL;
+	struct jx *result = NULL;
 	struct jx *j = NULL;
 	struct jx *new_ctx = NULL;
 
-	struct jx *val = jx_array_shift(args);
 	struct jx *objlist = jx_array_shift(args);
+	struct jx *val = jx_array_shift(args);
 	if (jx_array_length(args) != 0) {
 		result = make_error(func, args, "2 arguments required");
 		goto FAILURE;
@@ -886,7 +1032,7 @@ struct jx *jx_function_project(struct jx *args, struct jx *ctx) {
 	result = jx_array(0);
 
 	struct jx *item;
-	for(void *i = NULL; (item = jx_iterate_array(objlist, &i));) {
+	for (void *i = NULL; (item = jx_iterate_array(objlist, &i));) {
 		if (!jx_istype(item, JX_OBJECT)) {
 			jx_delete(result);
 			result = make_error(func, args, "list of objects required");
@@ -917,9 +1063,11 @@ FAILURE:
 	return result;
 }
 
-struct jx *jx_function_schema(struct jx *args) {
+struct jx *jx_function_schema(struct jx *args)
+{
 	assert(args);
-	if (jx_istype(args, JX_ERROR)) return args;
+	if (jx_istype(args, JX_ERROR))
+		return args;
 	const char *func = "schema";
 	struct jx *result = NULL;
 
@@ -936,14 +1084,12 @@ struct jx *jx_function_schema(struct jx *args) {
 	result = jx_object(0);
 
 	struct jx *item;
-	for(void *i = NULL; (item = jx_iterate_array(objlist, &i));) {
+	for (void *i = NULL; (item = jx_iterate_array(objlist, &i));) {
 		const char *key;
-		for(void *j = NULL; (key = jx_iterate_keys(item, &j));) {
-			if(!jx_lookup(result, key)) {
+		for (void *j = NULL; (key = jx_iterate_keys(item, &j));) {
+			if (!jx_lookup(result, key)) {
 				struct jx *lookup = jx_get_value(&j);
-				jx_insert(result,
-					jx_string(key),
-					jx_string(jx_type_string(lookup->type)));
+				jx_insert(result, jx_string(key), jx_string(jx_type_string(lookup->type)));
 			}
 		}
 	}
@@ -954,18 +1100,19 @@ FAILURE:
 	return result;
 }
 
-struct jx *jx_function_like(struct jx *args) {
+struct jx *jx_function_like(struct jx *args)
+{
 	assert(args);
-	if (jx_istype(args, JX_ERROR)) return args;
+	if (jx_istype(args, JX_ERROR))
+		return args;
 	const char *func = "like";
 	struct jx *result = NULL;
 
-	struct jx *val = jx_array_shift(args);
 	struct jx *obj = jx_array_shift(args);
+	struct jx *val = jx_array_shift(args);
 	if (!jx_istype(val, JX_STRING)) {
 		result = make_error(func, args, "1st argument must be a string");
 		goto FAILURE;
-
 	}
 	if (!jx_istype(obj, JX_STRING)) {
 		result = make_error(func, args, "2nd argument must be a string");
@@ -976,7 +1123,6 @@ struct jx *jx_function_like(struct jx *args) {
 		goto FAILURE;
 	}
 
-
 	int match = string_match_regex(obj->u.string_value, val->u.string_value);
 	result = jx_boolean(match);
 
@@ -987,4 +1133,4 @@ FAILURE:
 	return result;
 }
 
-/*vim: set noexpandtab tabstop=4: */
+/*vim: set noexpandtab tabstop=8: */
