@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2016- The University of Notre Dame
+Copyright (C) 2022 The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -8,6 +8,11 @@ See the file COPYING for details.
 #define JX_FUNCTION_H
 
 #include "jx.h"
+#include <stdio.h>
+
+struct jx *jx_function_eval(const char *funcname, struct jx *args, struct jx *ctx);
+struct jx *jx_function_sub(const char *funcname, struct jx *args, struct jx *ctx);
+void       jx_function_help(FILE *file);
 
 struct jx *jx_function_range(struct jx *args);
 struct jx *jx_function_format(struct jx *args);
