@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2015- The University of Notre Dame
+Copyright (C) 2022 The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -25,16 +25,22 @@ with the following exceptions:
 
 struct jx_parser;
 
-/** Parse a JSON string to a JX expression.  @param str A C string containing JSON data.  @return A JX expression which must be deleted with @ref jx_delete. If the parse fails or no JSON value is present, null is returned. */
+/* Sets module-wide flag for static parse mode */
+void jx_parse_set_static_mode( bool mode );
+
+/** Parse a JSON string to a JX expression.  @param str A null-terminated C string containing JSON data.  @return A JX expression which must be deleted with @ref jx_delete. If the parse fails or no JSON value is present, null is returned. */
 struct jx * jx_parse_string( const char *str );
 
+/** Parse a JSON string to a JX expression.  @param str An unterminated string containing JSON data.  @param Length of the string in bytes.  @return A JX expression which must be deleted with @ref jx_delete. If the parse fails or no JSON value is present, null is returned. */
+struct jx * jx_parse_string_and_length( const char *str, int length );
+
 /** Parse a standard IO stream to a JX expression.  @param file A stream containing JSON data.  @return A JX expression which must be deleted with @ref jx_delete. If the parse fails or no JSON value is present, null is returned. */
 struct jx * jx_parse_stream( FILE *file );
 
 /** Parse a file to a JX expression.  @param name The name of a file containing JSON data.  @return A JX expression which must be deleted with @ref jx_delete. If the parse fails or no JSON value is present, null is returned. */
 struct jx * jx_parse_file( const char *name );
 
-/** Parse a network link to a JX expression. @param l A @ref link object.  @param stoptime The absolute time at which to stop.   @return A JX expression which must be deleted with @ref jx_delete. If the parse fails or no JSON value is present, null is returned. */
+/** Parse a network link to a JX expression. @param l A link pointer (opaque struct).  @param stoptime The absolute time at which to stop.   @return A JX expression which must be deleted with @ref jx_delete. If the parse fails or no JSON value is present, null is returned. */
 struct jx * jx_parse_link( struct link *l, time_t stoptime );
 
 /** Parse a jx argument file from a commandline option.
@@ -60,10 +66,13 @@ struct jx_parser *jx_parser_create(bool strict_mode);
 /** Attach parser to a file.  @param p A parser object.  @param file A standard IO stream. */
 void jx_parser_read_stream( struct jx_parser *p, FILE *file );
 
-/** Attach parser to a string.  @param p A parser object.  @param str A JSON string to parse. */
+/** Attach parser to a null-terminate string.  @param p A parser object.  @param str A JSON string to parse. */
 void jx_parser_read_string( struct jx_parser *p, const char *str );
 
-/** Attach parser to a link.  @param p A parser object.  @param l A @ref link object.  @param stoptime The absolute time at which to stop. */
+/** Attach parser to a raw string with known length.  @param p A parser object.  @param str A JSON string to parse. @param length The length of the string in bytes. */
+void jx_parser_read_string_and_length( struct jx_parser *p, const char *str, int length );
+
+/** Attach parser to a link.  @param p A parser object.  @param l A link object.  @param stoptime The absolute time at which to stop. */
 void jx_parser_read_link( struct jx_parser *p, struct link *l, time_t stoptime );
 
 /** Parse and return a single value. This function is useful for streaming multiple independent values from a single source. @param p A parser object @return A JX expression which must be deleted with @ref jx_delete. If the parse fails or no JSON value is present, null is returned. */
