@@ -1,15 +1,15 @@
 /*
-Copyright (C) 2008- The University of Notre Dame
+Copyright (C) 2022 The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
 
-#if defined(CCTOOLS_OPSYS_DARWIN)
+#if defined(CCTOOLS_OPSYS_DARWIN) || defined(CCTOOLS_OPSYS_FREEBSD)
 
-#include <unistd.h>
 #include <stdlib.h>
 #include <sys/sysctl.h>
 #include <sys/types.h>
+#include <unistd.h>
 
 void load_average_get(double *avg)
 {
@@ -21,7 +21,7 @@ int load_average_get_cpus()
 {
 	int n;
 	size_t size = sizeof(n);
-	if(sysctlbyname("hw.ncpu", &n, &size, 0, 0) == 0) {
+	if (sysctlbyname("hw.physicalcpu", &n, &size, 0, 0) == 0) {
 		return n;
 	} else {
 		return 1;
@@ -31,13 +31,17 @@ int load_average_get_cpus()
 #elif defined(CCTOOLS_OPSYS_LINUX)
 
 #include <stdio.h>
+#include <stdlib.h>
+
+#include "string_set.h"
+#include "stringtools.h"
 
 void load_average_get(double *avg)
 {
 	FILE *f;
 	avg[0] = avg[1] = avg[2] = 0;
 	f = fopen("/proc/loadavg", "r");
-	if(f) {
+	if (f) {
 		fscanf(f, "%lf %lf %lf", &avg[0], &avg[1], &avg[2]);
 		fclose(f);
 	}
@@ -45,20 +49,32 @@ void load_average_get(double *avg)
 
 int load_average_get_cpus()
 {
-	FILE *f;
+	struct string_set *cores;
+	cores = string_set_create(0, 0);
+
+	for (int i = 0;; i++) {
+		char *p = string_format("/sys/devices/system/cpu/cpu%u/topology/thread_siblings", i);
+		FILE *f = fopen(p, "r");
+		free(p);
+		if (!f)
+			break;
 
-	f = fopen("/proc/cpuinfo", "r");
-	if(f) {
 		char line[1024];
-		int ncpus = 0;
-		while(fgets(line, sizeof(line), f)) {
-			sscanf(line, "processor : %d", &ncpus);
-		}
+		int rc = fscanf(f, "%1023s", line);
 		fclose(f);
-		return ncpus + 1;
-	} else {
-		return 1;
+		if (rc != 1)
+			break;
+
+		string_set_push(cores, line);
 	}
+
+	int cpus = string_set_size(cores);
+	string_set_delete(cores);
+	if (cpus < 1) {
+		cpus = 1;
+		fprintf(stderr, "Unable to detect CPUs, falling back to 1\n");
+	}
+	return cpus;
 }
 
 #else
@@ -75,4 +91,4 @@ int load_average_get_cpus()
 
 #endif
 
-/* vim: set noexpandtab tabstop=4: */
+/* vim: set noexpandtab tabstop=8: */
