@@ -39,6 +39,15 @@ See the file COPYING for details.
 #define TERABYTE TERA
 #define PETABYTE PETA
 
+#define BYTES_TO_STORAGE_UNIT(x, unit) (ceil(((double) x) / unit))
+#define BYTES_TO_KILOBYTES(x) BYTES_TO_STORAGE_UNIT(x, KILOBYTE)
+#define BYTES_TO_MEGABYTES(x) BYTES_TO_STORAGE_UNIT(x, MEGABYTE)
+#define BYTES_TO_GIGABYTES(x) BYTES_TO_STORAGE_UNIT(x, GIGABYTE)
+#define BYTES_TO_TERABYTES(x) BYTES_TO_STORAGE_UNIT(x, TERABYTE)
+#define BYTES_TO_PETABYTES(x) BYTES_TO_STORAGE_UNIT(x, PETABYTE)
+
+#define MEGABYTES_TO_BYTES(x) ((int64_t)(x) * MEGA)
+
 #define USECOND 1000000
 
 #endif
