@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014- The University of Notre Dame
+ * Copyright (C) 2022 The University of Notre Dame
  * This software is distributed under the GNU General Public License.
  * See the file COPYING for details.
  */
@@ -43,6 +43,12 @@ void    random_init (void);
  */
 int64_t random_int64 (void);
 
+/** Get a random double from (0, 1)
+ *
+ * @return a random double from (0, 1)
+ */
+double random_double (void);
+
 /** Insert random data into an array.
  *
  * @param m the memory to fill.
@@ -59,4 +65,4 @@ void    random_hex   (char *s, size_t l);
 
 #endif
 
-/* vim: set noexpandtab tabstop=4: */
+/* vim: set noexpandtab tabstop=8: */
