@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2003-2004 Douglas Thain and the University of Wisconsin
-Copyright (C) 2005- The University of Notre Dame
+Copyright (C) 2022 The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -36,6 +36,6 @@ int sort_dir(const char *dirname, char ***list, int (*sort) (const char *a, cons
 /** Free a sorted directory listing.
 @param list The list to be freed.
 */
-#define sort_dir_free free
+void sort_dir_free( char **list );
 
 #endif
