@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2003-2004 Douglas Thain and the University of Wisconsin
-Copyright (C) 2005- The University of Notre Dame
+Copyright (C) 2022 The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -57,7 +57,7 @@ static int ftp_lite_send_command_raw( struct ftp_lite_server *s, const char *lin
 {
 	char buf[FTP_LITE_LINE_MAX];
 	int length;
-	length = sprintf(buf,"%s\r\n",line);
+	length = snprintf(buf,FTP_LITE_LINE_MAX,"%s\r\n",line);
 	return(full_fwrite(s->command,buf,length)==length);
 }
 
@@ -1070,4 +1070,4 @@ int ftp_lite_auth_globus( struct ftp_lite_server *s )
 #endif
 
 
-/* vim: set noexpandtab tabstop=4: */
+/* vim: set noexpandtab tabstop=8: */
