@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2003-2004 Douglas Thain and the University of Wisconsin
-Copyright (C) 2005- The University of Notre Dame
+Copyright (C) 2022 The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -77,8 +77,8 @@ int ftp_lite_radix_decode( const unsigned char *inbuf, unsigned char *outbuf, in
 {
 	int i;
 	int j;
-	int D;
-	char *p;
+	int D = 0;
+	char *p = NULL;
 
 	for (i=0,j=0; inbuf[i] && inbuf[i] != pad; i++)
 	{
@@ -135,4 +135,4 @@ int ftp_lite_radix_decode( const unsigned char *inbuf, unsigned char *outbuf, in
 	return 1;
 }
 
-/* vim: set noexpandtab tabstop=4: */
+/* vim: set noexpandtab tabstop=8: */
