@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2013- The University of Notre Dame
+Copyright (C) 2022 The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -17,7 +17,7 @@ See the file COPYING for details.
 #include "cctools.h"
 #include "copy_stream.h"
 #include "create_dir.h"
-#include "delete_dir.h"
+#include "unlink_recursive.h"
 #include "debug.h"
 #include "getopt_aux.h"
 #include "list.h"
@@ -216,7 +216,7 @@ struct list *find_dependencies_for(struct dependency *dep){
 		close(pipefd[1]);
 		char next;
 		char *buffer = (char *) malloc(sizeof(char));
-		char *original_name;
+		char *original_name = NULL;
 		int size = 0;
 		int depth = dep->depth  + 1;
 		struct list *new_deps = list_create();
@@ -417,7 +417,7 @@ static void show_help(const char *cmd){
 
 void cleanup(){
 	if(workspace){
-		if(delete_dir(workspace) != 0) fprintf(stderr, "Could not delete workspace (%s)\n", workspace);
+		if(unlink_recursive(workspace) != 0) fprintf(stderr, "Could not delete workspace (%s)\n", workspace);
 		if(verbose) fprintf(stdout, "Deleted temporary workspace: %s\n", workspace);
 		free(workspace);
 	}
