@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2018- The University of Notre Dame
+ Copyright (C) 2022 The University of Notre Dame
  This software is distributed under the GNU General Public License.
  See the file COPYING for details.
  */
@@ -9,7 +9,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 
-#include "batch_task.h"
+#include "batch_job.h"
 #include "batch_wrapper.h"
 #include "debug.h"
 #include "path.h"
@@ -92,7 +92,7 @@ static int dag_check( void * instance_struct, struct dag *d){
 	return MAKEFLOW_HOOK_SUCCESS;
 }
 
-static int node_submit( void * instance_struct, struct dag_node *n, struct batch_task *t){
+static int node_submit( void * instance_struct, struct dag_node *n, struct batch_job *t){
 	struct docker_instance *d = (struct docker_instance*)instance_struct;
 	
 	struct batch_wrapper *wrapper = batch_wrapper_create();
@@ -120,7 +120,7 @@ static int node_submit( void * instance_struct, struct dag_node *n, struct batch
 
 	cmd = batch_wrapper_write(wrapper, t);
 	if(cmd){
-		batch_task_set_command(t, cmd);
+		batch_job_set_command(t, cmd);
 		struct dag_file *df = makeflow_hook_add_input_file(n->d, t, cmd, cmd, DAG_FILE_TYPE_TEMP);
 		debug(D_MAKEFLOW_HOOK, "Wrapper written to %s", df->filename);
 		makeflow_log_file_state_change(n->d, df, DAG_FILE_STATE_EXISTS);
