@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2019- The University of Notre Dame
+Copyright (C) 2022 The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -107,12 +107,18 @@ static int resources_from_jx(struct hash_table *h, struct jx *j, int nodeid)
 				debug(D_MAKEFLOW_PARSER, "%d memory", memory);
 				dag_variable_add_value(RESOURCES_MEMORY, h, nodeid, string_format("%d", memory));
 			}
-		} else if(!strcmp(key, "memory")) {
+		} else if(!strcmp(key, "gpus")) {
 			int gpus = jx_lookup_integer(j, "gpus");
-			if(gpus) {
+			if(gpus > -1) {  // Note that when "gpus" is missing, this defaults to 0
 				debug(D_MAKEFLOW_PARSER, "%d gpus", gpus);
 				dag_variable_add_value(RESOURCES_GPUS, h, nodeid, string_format("%d", gpus));
 			}
+		} else if(!strcmp(key, "mpi-processes")) {
+			int procs = jx_lookup_integer(j, "mpi-processes");
+			if(procs) {
+				debug(D_MAKEFLOW_PARSER, "%d mpi-processes", procs);
+				dag_variable_add_value(RESOURCES_MPI_PROCESSES, h, nodeid, string_format("%d", procs));
+			}
 		} else if(!strcmp(key, "wall-time")) {
 			int wall_time = jx_lookup_integer(j, "wall-time");
 			if(wall_time) {
