@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2008- The University of Notre Dame
+Copyright (C) 2022 The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -30,7 +30,7 @@ See the file COPYING for details.
 #include "hash_table.h"
 #include "itable.h"
 #include "debug.h"
-#include "delete_dir.h"
+#include "unlink_recursive.h"
 #include "stringtools.h"
 #include "load_average.h"
 #include "get_line.h"
@@ -367,7 +367,7 @@ static int dag_parse_make_directive_MAKEFLOW(struct lexer *bk, struct dag_node *
 
 	if(t->type != TOKEN_LITERAL)
 	{
-		lexer_report_error(bk, "Expected LITERAL token (CATEGORY|MODE|CORES|DISK|MEMORY|SIZE), got: %s\n", lexer_print_token(t));
+		lexer_report_error(bk, "Expected LITERAL token (CATEGORY|MODE|CORES|DISK|MEMORY|WALL_TIME|SIZE|MPI_PROCESSES), got: %s\n", lexer_print_token(t));
 	}
 
 	struct token *t2 = lexer_next_token(bk);
@@ -387,7 +387,9 @@ static int dag_parse_make_directive_MAKEFLOW(struct lexer *bk, struct dag_node *
 	}
 	else if((   !strcmp("CORES",  t->lexeme))
 			|| (!strcmp("DISK",   t->lexeme))
-			|| (!strcmp("MEMORY", t->lexeme)))
+			|| (!strcmp("MEMORY", t->lexeme))
+			|| (!strcmp("WALL_TIME", t->lexeme))
+			|| (!strcmp("MPI_PROCESSES", t->lexeme)))
 	{
 		if(!(string_metric_parse(t2->lexeme) >= 0))
 		{
@@ -426,7 +428,7 @@ static int dag_parse_make_directive_MAKEFLOW(struct lexer *bk, struct dag_node *
 	}
 	else
 	{
-		lexer_report_error(bk, "Unsupported .MAKEFLOW directive, expected (CATEGORY|MODE|CORES|DISK|MEMORY|SIZE), got: %s\n", t->lexeme);
+		lexer_report_error(bk, "Unsupported .MAKEFLOW directive, expected (CATEGORY|MODE|CORES|DISK|MEMORY|WALL_TIME|SIZE|MPI_PROCESSES), got: %s\n", t->lexeme);
 	}
 
 	if(set_var) {
