@@ -6,11 +6,11 @@ if [ $OSNAME = Darwin ]
 then
     # On macos, conda is not installed in the environment by default.
     # So we deploy it here, and then are force to source bash_profile in every step.
-    mkdir -p ~/miniconda3
-    curl https://repo.anaconda.com/miniconda/Miniconda3-latest-MacOSX-x86_64.sh -o ~/miniconda3/miniconda.sh
-    bash ~/miniconda3/miniconda.sh -b -u -p ~/miniconda3
+    mkdir -p ~/miniforge3
+    curl -L "https://github.com/conda-forge/miniforge/releases/latest/download/Miniforge3-$(uname)-$(uname -m).sh" -o ~/miniforge3/miniforge.sh
+    bash ~/miniforge3/miniforge.sh -b -u -p ~/miniforge3
     # This adds the conda configuration to bash_profile, which is executed once at login.
-    ~/miniconda3/bin/conda init bash
+    ~/miniforge3/bin/conda init bash
     # Now we pull in the configuration.
     source ~/.bash_profile
     # Install mamba for faster solves.
