@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2008- The University of Notre Dame
+Copyright (C) 2022 The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -24,7 +24,7 @@ int main( int argc, char *argv[] )
 
 	for(i=1;i<argc;i++) {
 		if(parrot_md5(argv[i],digest)>=0 || md5_file(argv[i],digest)) {
-			printf("%s %s\n",md5_string(digest),argv[i]);
+			printf("%s %s\n",md5_to_string(digest),argv[i]);
 		} else {
 			fprintf(stderr,"parrot_md5: %s: %s\n",argv[i],strerror(errno));
 		}
