@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009- The University of Notre Dame
+Copyright (C) 2022 The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -53,7 +53,7 @@ extern "C" {
 
 #define BXGRID_END	debug(D_BXGRID,"= %d %s",(int)result,((result>=0) ? "" : strerror(errno))); return result;
 
-extern int pfs_master_timeout;
+extern int pfs_main_timeout;
 
 static int bxgrid_timeout = BXGRID_TIMEOUT;
 
@@ -172,11 +172,11 @@ public:
 	}
 
 	virtual int close() {
-		return chirp_global_close(file,time(0)+pfs_master_timeout);
+		return chirp_global_close(file,time(0)+pfs_main_timeout);
 	}
 
 	virtual pfs_ssize_t read( void *data, pfs_size_t length, pfs_off_t offset ) {
-		return chirp_global_pread(file,data,length,offset,time(0)+pfs_master_timeout);
+		return chirp_global_pread(file,data,length,offset,time(0)+pfs_main_timeout);
 	}
 
 	virtual int fstat( struct pfs_stat *buf );
@@ -469,7 +469,7 @@ pfs_file *bxgrid_bvf_open( MYSQL *mysql_cxn, struct bxgrid_virtual_folder *bvf,
 		} else {
 			replicaid = NULL;
 		}
-	} while (replicaid && time(0) - start_time < pfs_master_timeout);
+	} while (replicaid && time(0) - start_time < pfs_main_timeout);
 
 	return 0;
 }
@@ -725,7 +725,7 @@ public:
 
 		if (this->_stat(mysql_cxn, name, &buf) >= 0) {
 			const char *fileid, *replicaid;
-			char host[PFS_PATH_MAX], path[PFS_PATH_MAX], location[PFS_PATH_MAX];
+			char host[PFS_PATH_MAX], path[PFS_PATH_MAX];
 			struct bxgrid_virtual_folder *bvf;
 
 			if (S_ISDIR(buf.st_mode)) {
@@ -740,15 +740,17 @@ public:
 					fileid = path_basename(name->rest);
 					while ((replicaid = bxgrid_lookup_replicaid(mysql_cxn, fileid, nid++))) {
 						if (bxgrid_lookup_replica_location(mysql_cxn, replicaid, host, path) >= 0) {
-							snprintf(location, PFS_PATH_MAX, "%s:%s", host, path);
-							loc->append(location);
+							char *tmp = string_format("%s:%s", host, path);
+							loc->append(tmp);
+							free(tmp);
 						}
 					}
 				} else {
 					replicaid = path_basename(name->rest);
 					if (bxgrid_lookup_replica_location(mysql_cxn, replicaid, host, path) >= 0) {
-						snprintf(location, PFS_PATH_MAX, "%s:%s", host, path);
-						loc->append(location);
+						char *tmp = string_format("%s:%s", host, path);
+						loc->append(tmp);
+						free(tmp);
 					}
 				}
 			}
@@ -778,4 +780,4 @@ int pfs_file_bxgrid::fstat( struct pfs_stat *buf ) {
 
 #endif
 
-/* vim: set noexpandtab tabstop=4: */
+/* vim: set noexpandtab tabstop=8: */
