@@ -40,7 +40,7 @@ extern "C" {
 #include <string>
 #include <list>
 
-extern int pfs_master_timeout;
+extern int pfs_main_timeout;
 extern char pfs_temp_dir[];
 extern const char * pfs_cvmfs_repo_arg;
 extern const char * pfs_cvmfs_config_arg;
@@ -657,8 +657,8 @@ static cvmfs_filesystem *cvmfs_filesystem_create(const char *repo_name, bool wil
 			enable_alien_on_this_repository ? repo_name : "",
 			enable_alien_on_this_repository ? "," : "",
 
-			pfs_master_timeout,
-			pfs_master_timeout,
+			pfs_main_timeout,
+			pfs_main_timeout,
 			pfs_cvmfs_http_proxy ? ",proxies=" : "",
 			pfs_cvmfs_http_proxy ? pfs_cvmfs_http_proxy : "",
 			&f->subst_offset,
@@ -668,8 +668,8 @@ static cvmfs_filesystem *cvmfs_filesystem_create(const char *repo_name, bool wil
 			&repo_name_offset,
 			repo_name,
 
-			pfs_master_timeout,
-			pfs_master_timeout,
+			pfs_main_timeout,
+			pfs_main_timeout,
 			pfs_cvmfs_http_proxy ? ",proxies=" : "",
 			pfs_cvmfs_http_proxy ? pfs_cvmfs_http_proxy : "",
 			&f->subst_offset,
@@ -1136,7 +1136,7 @@ static bool path_expand_symlink(struct pfs_name *path, struct pfs_name *xpath)
 
 	memcpy(xpath, path, sizeof(pfs_name));
 	xpath->rest[0] = '\0';
-	strncpy(path_tail, path->rest, PFS_PATH_MAX);
+	strncpy(path_tail, path->rest, PFS_PATH_MAX - 1);
 
 	do
 	{
@@ -1175,9 +1175,9 @@ static bool path_expand_symlink(struct pfs_name *path, struct pfs_name *xpath)
 					char path_relative[PFS_PATH_MAX];
 					*(last_d + 1) = '\0';
 
-					strncat(xpath->rest, link_target, PFS_PATH_MAX);
+					strncat(xpath->rest, link_target, PFS_PATH_MAX - 1);
 					path_collapse(xpath->rest, path_relative, 1);
-					snprintf(link_target, PFS_PATH_MAX, "/cvmfs/%s%s",
+					string_nformat(link_target, PFS_PATH_MAX - 1, "/cvmfs/%s%s",
 						 xpath->host, path_relative);
 				}
 			}
@@ -1190,8 +1190,8 @@ static bool path_expand_symlink(struct pfs_name *path, struct pfs_name *xpath)
 				return false;
 			}
 
-			snprintf(xpath->rest, PFS_PATH_MAX, "%s%s", path_head, path_tail);
-			snprintf(xpath->path, PFS_PATH_MAX, "/cvmfs/%s%s", xpath->host, xpath->rest);
+			string_nformat(xpath->rest, PFS_PATH_MAX, "%s%s", path_head, path_tail);
+			string_nformat(xpath->path, PFS_PATH_MAX, "/cvmfs/%s%s", xpath->host, xpath->rest);
 			strcpy(xpath->logical_name, xpath->path);
 
 			debug(D_CVMFS, "expanding symlinks %s to %s\n", path->path, xpath->path);
@@ -1598,4 +1598,4 @@ pfs_service *pfs_service_cvmfs = &pfs_service_cvmfs_instance;
 
 #endif
 
-/* vim: set noexpandtab tabstop=4: */
+/* vim: set noexpandtab tabstop=8: */
