@@ -38,8 +38,6 @@
 # - @ref ndcctools.taskvine.dask_executor.DaskVine "vine.DaskVine"
 #
 
-import warnings
-
 from .manager import (
     Manager,
     Factory,
@@ -71,23 +69,14 @@ try:
     vd = Version(dask.__version__)
     vr = Version("2024.12.0")
     if vd < vr:
-        warnings.warn("ndcctools.taskvine.DaskVine only works with dask version >= 2024.12.0", DaskVineWarning)
+        raise ImportError
 
     from .dask_executor import DaskVine
     from .dask_dag import DaskVineDag
-except ImportError as e:
-    warnings.warn(f"DaskVine not available. Couldn't find module: {e.name}", DaskVineWarning)
+except (ImportError, ModuleNotFoundError):
+    from .compat import DaskVine
+    from .compat import DaskVineDag
 
-    ##
-    # DaskVine compatibility class.
-    # See @ref dask_executor.DaskVine
-    class DaskVine:
-        exception = ImportError()
-
-        def __init__(*args, **kwargs):
-            raise DaskVine.exception
-
-    DaskVine.exception = e
 
 __all__ = [
     "Manager",
