@@ -107,7 +107,7 @@ class DaskVine(Manager):
     #                      fn(*args) at some point during its execution to produce the dask task result.
     #                      Should return a tuple of (wrapper result, dask call result). Use for debugging.
     # @param wrapper_proc  Function to process results from wrapper on completion. (default is print)
-    # @param prune_files If True, remove files from the cluster after they are no longer needed.
+    # @param prune_depth Control pruning behavior: 0 (default) - no pruning, 1 - only check direct consumers, 2+ - check consumers up to specified depth
     def get(self, dsk, keys, *,
             environment=None,
             extra_files=None,
@@ -126,13 +126,15 @@ class DaskVine(Manager):
             lib_command=None,
             lib_modules=None,
             task_mode='tasks',
-            scheduling_mode='FIFO',
+            task_priority_mode='largest-input-first',
+            scheduling_mode="files",
             env_per_task=False,
+            init_command=None,
             progress_disable=False,
             progress_label="[green]tasks",
             wrapper=None,
             wrapper_proc=print,
-            prune_files=False,
+            prune_depth=0,
             hoisting_modules=None,  # Deprecated, use lib_modules
             import_modules=None,    # Deprecated, use lib_modules
             lazy_transfers=True,    # Deprecated, use worker_tranfers
@@ -168,13 +170,15 @@ class DaskVine(Manager):
             else:
                 self.lib_modules = hoisting_modules if hoisting_modules else import_modules  # Deprecated
             self.task_mode = task_mode
-            self.scheduling_mode = scheduling_mode
+            self.task_priority_mode = task_priority_mode
+            self.set_scheduler(scheduling_mode)
             self.env_per_task = env_per_task
+            self.init_command = init_command
             self.progress_disable = progress_disable
             self.progress_label = progress_label
             self.wrapper = wrapper
             self.wrapper_proc = wrapper_proc
-            self.prune_files = prune_files
+            self.prune_depth = prune_depth
             self.category_info = defaultdict(lambda: {"num_tasks": 0, "total_execution_time": 0})
             self.max_priority = float('inf')
             self.min_priority = float('-inf')
@@ -212,7 +216,7 @@ class DaskVine(Manager):
         indices = {k: inds for (k, inds) in find_dask_keys(keys)}
         keys_flatten = indices.keys()
 
-        dag = DaskVineDag(dsk, low_memory_mode=self.low_memory_mode)
+        dag = DaskVineDag(dsk, low_memory_mode=self.low_memory_mode, prune_depth=self.prune_depth)
         tag = f"dag-{id(dag)}"
 
         # create Library if using 'function-calls' task mode.
@@ -294,8 +298,12 @@ class DaskVine(Manager):
                         if t.key in dsk:
                             bar_update(advance=1)
 
-                        if self.prune_files:
-                            self._prune_file(dag, t.key)
+                        if self.prune_depth > 0:
+                            for p in dag.pending_producers[t.key]:
+                                dag.pending_consumers[p] -= 1
+                                if dag.pending_consumers[p] == 0:
+                                    p_result = dag.get_result(p)
+                                    self.prune_file(p_result._file)
                     else:
                         retries_left = t.decrement_retry()
                         print(f"task id {t.id} key {t.key} failed: {t.result}. {retries_left} attempts left.\n{t.std_output}")
@@ -349,37 +357,45 @@ class DaskVine(Manager):
             cat = self.category_name(sexpr)
 
             task_depth = dag.depth_of(k)
-            if self.scheduling_mode == 'random':
+            if self.task_priority_mode == 'random':
                 priority = random.randint(self.min_priority, self.max_priority)
-            elif self.scheduling_mode == 'depth-first':
+            elif self.task_priority_mode == 'depth-first':
                 # dig more information about different kinds of tasks
                 priority = task_depth
-            elif self.scheduling_mode == 'breadth-first':
+            elif self.task_priority_mode == 'breadth-first':
                 # prefer to start all branches as soon as possible
                 priority = -task_depth
-            elif self.scheduling_mode == 'longest-category-first':
+            elif self.task_priority_mode == 'longest-category-first':
                 # if no tasks have been executed in this category, set a high priority so that we know more information about each category
                 if self.category_info[cat]["num_tasks"]:
                     priority = self.category_info[cat]["total_execution_time"] / self.category_info[cat]["num_tasks"]
                 else:
                     priority = self.max_priority
-            elif self.scheduling_mode == 'shortest-category-first':
+            elif self.task_priority_mode == 'shortest-category-first':
                 # if no tasks have been executed in this category, set a high priority so that we know more information about each category
                 if self.category_info[cat]["num_tasks"]:
                     priority = -self.category_info[cat]["total_execution_time"] / self.category_info[cat]["num_tasks"]
                 else:
                     priority = self.max_priority
-            elif self.scheduling_mode == 'FIFO':
+            elif self.task_priority_mode == 'FIFO':
                 # first in first out, the default behavior
                 priority = -round(time.time(), 6)
-            elif self.scheduling_mode == 'LIFO':
+            elif self.task_priority_mode == 'LIFO':
                 # last in first out, the opposite of FIFO
                 priority = round(time.time(), 6)
-            elif self.scheduling_mode == 'largest-input-first':
-                # best for saving disk space (with pruing)
+            elif self.task_priority_mode == 'largest-input-first':
+                # best for saving disk space (with pruning)
                 priority = sum([len(dag.get_result(c)._file) for c in dag.get_children(k)])
+            elif self.task_priority_mode == 'largest-storage-footprint-first':
+                # prioritize tasks that can consume larger or longer-retained inputs
+                storage_footprint = 0
+                for c in dag.get_children(k):
+                    file_result = dag.get_result(c)
+                    if isinstance(file_result, DaskVineFile):
+                        storage_footprint += len(file_result._file) * (time.time() - dag.get_result_set_time(c))
+                priority = storage_footprint
             else:
-                raise ValueError(f"Unknown scheduling mode {self.scheduling_mode}")
+                raise ValueError(f"Unknown task priority mode {self.task_priority_mode}")
 
             if self.task_mode == 'tasks':
                 if cat not in self._categories_known:
@@ -408,6 +424,9 @@ class DaskVine(Manager):
                         f"mkdir envdir && tar -xf {self._environment_name} -C envdir && envdir/bin/run_in_env {t._command}")
                     t.add_input(self.environment_file, self.environment_name)
 
+                if self.init_command:
+                    t.set_command(f"{self.init_command} {t.command}")
+
                 t.set_tag(tag)  # tag that identifies this dag
                 enqueued_calls.append(t)
 
@@ -446,14 +465,6 @@ class DaskVine(Manager):
             return raw.load()
         else:
             return raw
-
-    def _prune_file(self, dag, key):
-        children = dag.get_children(key)
-        for c in children:
-            if len(dag.get_pending_parents(c)) == 0:
-                c_result = dag.get_result(c)
-                self.prune_file(c_result._file)
-
 ##
 # @class ndcctools.taskvine.dask_executor.DaskVineFile
 #
