@@ -1,30 +1,33 @@
-
 from . import cvine
 import hashlib
-from concurrent.futures import Executor
-from concurrent.futures import Future
-from concurrent.futures import FIRST_COMPLETED
-from concurrent.futures import FIRST_EXCEPTION
-from concurrent.futures import ALL_COMPLETED
-from concurrent.futures._base import PENDING
-from concurrent.futures._base import CANCELLED
-from concurrent.futures._base import FINISHED
+from collections import deque, namedtuple
+from concurrent.futures import (
+    Executor,
+    Future,
+    FIRST_COMPLETED,
+    FIRST_EXCEPTION,
+    ALL_COMPLETED,
+)
+from concurrent.futures._base import PENDING, CANCELLED, FINISHED
 from concurrent.futures import TimeoutError
-from collections import namedtuple
+
 from .task import (
     PythonTask,
     FunctionCall,
-    PythonTaskNoResult,
     FunctionCallNoResult,
 )
+
 from .manager import (
     Factory,
     Manager,
 )
 
+import math
 import os
 import time
 import textwrap
+from functools import partial
+from collections.abc import Sequence
 
 RESULT_PENDING = 'result_pending'
 
@@ -53,44 +56,44 @@ def wait(fs, timeout=None, return_when=ALL_COMPLETED):
         if not f._is_submitted:
             f.module_manager.submit(f._task)
 
-    time_init = time.time()
-    if timeout is None:
-        time_check = float('inf')
-    else:
-        time_check = timeout
-    done = False
-    while time.time() - time_init < time_check and not done:
-        done = True
-        for f in fs:
+    start = time.perf_counter()
+    time_check = float('inf') if timeout is None else timeout
+    result_timeout = min(timeout, 5) if timeout is not None else 5
 
+    done = False
+    while time.perf_counter() - start < time_check and not done:
+        for f in fs:
             # skip if future is complete
             if f in results.done:
                 continue
 
-            # check for completion
-            result = f.result(timeout=5)
-
-            # add to set of finished tasks and break when needed.
-            if result != RESULT_PENDING:
+            try:
+                # check for completion
+                f.result(timeout=result_timeout)
+            except TimeoutError:
+                # TimeoutError's are expected since we are polling the
+                # future's status. If a timeout happens, we do nothing.
+                pass
+            except Exception:
+                # Future.result() raises the task's exception but that is
+                # not relevant here---just if the task has finished.
+                results.done.add(f)
+                if return_when in (FIRST_EXCEPTION, FIRST_COMPLETED):
+                    done = True
+                    break
+            else:
                 results.done.add(f)
-
-                # if this is the first completed task, break.
                 if return_when == FIRST_COMPLETED:
                     done = True
                     break
 
-            if isinstance(result, Exception) and return_when == FIRST_EXCEPTION:
+            if len(results.done) == len(fs):
                 done = True
                 break
 
-            # set done to false to finish loop.
-            else:
-                done = False
-
             # check form timeout
-            if timeout is not None:
-                if time.time() - time_init > timeout:
-                    break
+            if time.perf_counter() - start > time_check:
+                break
 
     # add incomplete futures to set
     for f in fs:
@@ -101,57 +104,71 @@ def wait(fs, timeout=None, return_when=ALL_COMPLETED):
 
 
 def as_completed(fs, timeout=None):
+    fs = deque(fs)
 
-    results = set()
-
-    # submit tasks if they have not been subitted
+    # submit tasks if they have not been submitted
     for f in fs:
         if not f._is_submitted:
             f.module_manager.submit(f._task)
 
-    time_init = time.time()
-    if timeout is None:
-        time_check = float('inf')
-    else:
-        time_check = timeout
+    start = time.perf_counter()
+    result_timeout = max(1, min(timeout, 5)) if timeout else 5
 
-    done = False
-    while time.time() - time_init < time_check and not done:
-        for f in fs:
-            done = True
-            # skip if future is complete
-            if f in results:
-                continue
+    def _iterator():
+        # iterate of queue of futures, yeilding completed futures and
+        # requeuing non-completed futures until all futures are yielded or
+        # the timeout is reached.
+        while fs:
+            f = fs.popleft()
 
-            # check for completion
-            result = f.result(timeout=5)
-
-            # add to set of finished tasks
-            if result != RESULT_PENDING:
-                results.add(f)
-
-            # set done to false to finish loop.
+            try:
+                result = f.result(timeout=result_timeout)
+            except TimeoutError:
+                # TimeoutError's are expected since we are polling the
+                # future's status. If a timeout happens, add the future to
+                # the back of the queue.
+                fs.append(f)
+            except Exception:
+                # Future.result() raises the task's exception but that is
+                # not relevant here---just if the task has finished.
+                yield f
             else:
-                done = False
+                assert result != RESULT_PENDING
+                yield f
 
-            # check form timeout
-            if timeout is not None:
-                if time.time() - time_init > timeout:
-                    break
-    for f in fs:
-        if f not in results:
-            results.add(TimeoutError)
+            if fs and timeout and time.perf_counter() - start > timeout:
+                raise TimeoutError()
 
-    return iter(results)
+    return _iterator()
 
 
+def run_iterable(fn, *args):
+    return list(map(fn, args))
+
+
+def reduction_tree(fn, *args, n=2):
+    # n is the arity of the reduction function fn
+    # if less than 2, we have an infinite loop
+    assert n > 1
+    entries = [f.result() if isinstance(f, VineFuture) else f for f in args]
+    if len(entries) < 2:
+        return entries[0]
+
+    len_multiple = int(math.ceil(len(entries) / n) * n)
+    new_args = map(fn, [entries[i:i + n] for i in range(0, len_multiple, n)])
+
+    return reduction_tree(fn, *new_args, n=n)
+
 ##
 # \class FuturesExecutor
 #
 # TaskVine FuturesExecutor object
 #
 # This class acts as an interface for the creation of Futures
+
+
 class FuturesExecutor(Executor):
+
     def __init__(self, port=9123, batch_type="local", manager=None, manager_host_port=None, manager_name=None, factory_binary=None, worker_binary=None, log_file=os.devnull, factory=True, opts={}):
         self.manager = Manager(port=port)
         self.port = self.manager.port
@@ -176,21 +193,109 @@ class FuturesExecutor(Executor):
         else:
             self.factory = None
 
+    def map(self, fn, iterable, library_name=None, chunk_size=1):
+        assert chunk_size > 0
+        assert isinstance(iterable, Sequence)
+
+        def wait_for_map_resolution(*futures_batch):
+            result = []
+            for f in futures_batch:
+                result.extend(f.result() if isinstance(f, VineFuture) else f)
+            return result
+
+        tasks = []
+        fn_wrapped = partial(run_iterable, fn)
+        while iterable:
+            heads, iterable = iterable[:chunk_size], iterable[chunk_size:]
+
+            if library_name:
+                raise NotImplementedError("Using a library not currently supported.")
+                future_batch_task = self.submit(self.future_funcall(library_name, fn_wrapped, *heads))
+            else:
+                future_batch_task = self.submit(self.future_task(fn_wrapped, *heads))
+
+            tasks.append(future_batch_task)
+
+        return self.submit(self.future_task(wait_for_map_resolution, *tasks))
+
+    # Reduce performs a reduction tree on the iterable and currently returns a single value
+    #
+    # parameters:
+    # - Function
+    # - a function that receives fn_arity arguments
+    # - A sequence of parameters that function will take
+    # - a chunk_size to group elements in sequence to dispatch to a single task
+    # - arity of the function, elements of a chunk are reduce arity-wise.
+    # - an optional library_name for a library function call
+    def reduce(self, fn, iterable, library_name=None, chunk_size=2, fn_arity=2):
+        assert chunk_size > 1
+        assert fn_arity > 1
+        assert isinstance(iterable, Sequence)
+        chunk_size = max(fn_arity, chunk_size)
+
+        new_iterable = []
+        while iterable:
+            heads, iterable = iterable[:chunk_size], iterable[chunk_size:]
+            heads = [f.result() if isinstance(f, VineFuture) else f for f in heads]
+            if library_name:
+                raise NotImplementedError("Using a library not currently supported.")
+                future_batch_task = self.submit(
+                    self.future_funcall(
+                        library_name, reduction_tree, fn, *heads, n=fn_arity
+                    )
+                )
+            else:
+                future_batch_task = self.submit(self.future_task(reduction_tree, fn, *heads, n=fn_arity))
+
+            new_iterable.append(future_batch_task)
+
+        if len(new_iterable) > 1:
+            return self.reduce(fn, new_iterable, library_name, chunk_size, fn_arity)
+        else:
+            return new_iterable[0]
+
+    def allpairs(self, fn, iterable_rows, iterable_cols, library_name=None, chunk_size=1):
+        assert chunk_size > 0
+        assert isinstance(iterable_rows, Sequence)
+        assert isinstance(iterable_cols, Sequence)
+
+        def wait_for_allpairs_resolution(row_size, col_size, mapped):
+            result = []
+            for _ in range(row_size):
+                result.append([0] * col_size)
+
+            mapped = mapped.result() if isinstance(mapped, VineFuture) else mapped
+            for p in mapped:
+                (i, j, r) = p.result() if isinstance(p, VineFuture) else p
+                result[i][j] = r
+
+            return result
+
+        def wrap_idx(args):
+            i, j, a, b = args
+            return (i, j, fn(a, b))
+
+        iterable = [(i, j, a, b) for (i, a) in enumerate(iterable_rows) for (j, b) in enumerate(iterable_cols)]
+        mapped = self.map(wrap_idx, iterable, library_name, chunk_size)
+
+        return self.submit(
+            self.future_task(
+                wait_for_allpairs_resolution,
+                len(iterable_rows),
+                len(iterable_cols),
+                mapped,
+            )
+        )
+
     def submit(self, fn, *args, **kwargs):
-        if isinstance(fn, FuturePythonTask):
+        if isinstance(fn, (FuturePythonTask, FutureFunctionCall)):
             self.manager.submit(fn)
             fn._future._is_submitted = True
-            return fn._future
-        if isinstance(fn, FutureFunctionCall):
-            self.manager.submit(fn)
             self.task_table.append(fn)
-            fn._future._is_submitted = True
             return fn._future
-        future_task = self.future_task(fn, *args, **kwargs)
-        self.task_table.append(future_task)
-        future_task._future._is_submitted = True
-        self.submit(future_task)
-        return future_task._future
+        else:
+            future_task = self.future_task(fn, *args, **kwargs)
+            return self.submit(future_task)
 
     def future_task(self, fn, *args, **kwargs):
         return FuturePythonTask(self.manager, fn, *args, **kwargs)
@@ -233,6 +338,7 @@ class VineFuture(Future):
         self._task = task
         self._callback_fns = []
         self._result = None
+        self._exception = None
         self._is_submitted = False
         self._ran_functions = False
 
@@ -266,15 +372,30 @@ class VineFuture(Future):
             timeout = "wait_forever"
         result = self._task.output(timeout=timeout)
         if result == RESULT_PENDING:
-            return RESULT_PENDING
+            raise TimeoutError()
+
+        if isinstance(result, Exception):
+            self._exception = result
         else:
             self._result = result
-            self._state = FINISHED
-            if self._callback_fns and not self._ran_functions:
-                self._ran_functions = True
-                for fn in self._callback_fns:
-                    fn(self)
-            return result
+
+        self._state = FINISHED
+        if self._callback_fns and not self._ran_functions:
+            self._ran_functions = True
+            for fn in self._callback_fns:
+                fn(self)
+
+        if isinstance(result, Exception):
+            raise result
+        return result
+
+    def exception(self, timeout="wait_forever"):
+        try:
+            self.result()
+        except Exception as e:
+            return e
+        else:
+            return None
 
     def add_done_callback(self, fn):
         self._callback_fns.append(fn)
@@ -294,7 +415,6 @@ class FutureFunctionCall(FunctionCall):
         self.manager = manager
         self.library_name = library_name
         self._envs = []
-
         self._future = VineFuture(self)
         self._has_retrieved = False
 
@@ -318,11 +438,9 @@ class FutureFunctionCall(FunctionCall):
                     if output['Success']:
                         self._saved_output = output['Result']
                     else:
-                        self._saved_output = output['Reason']
-
+                        self._saved_output = FunctionCallNoResult(output['Reason'])
                 except Exception as e:
                     self._saved_output = e
-                    raise e
             else:
                 self._saved_output = FunctionCallNoResult()
             self._output_loaded = True
@@ -388,15 +506,15 @@ class FuturePythonTask(PythonTask):
 
         # fetch output file and load output
         if not self._output_loaded and self._has_retrieved:
-            if self.successful():
-                try:
-                    self._module_manager.fetch_file(self._output_file)
-                    self._output = cloudpickle.loads(self._output_file.contents())
-                except Exception as e:
-                    self._output = e
-                    raise e
-            else:
-                self._output = PythonTaskNoResult()
+            try:
+                self._module_manager.fetch_file(self._output_file)
+                # _output can be either the return value of a successful
+                # task or the exception object of a failed task.
+                self._output = cloudpickle.loads(self._output_file.contents())
+            except Exception as e:
+                print(self._output_file.contents())
+                # handle output file fetch/deserialization failures
+                self._output = e
             self._output_loaded = True
 
         return self._output
@@ -449,6 +567,7 @@ class FuturePythonTask(PythonTask):
                         args = [vineLoadArg(arg) if isinstance(arg, dict) and "VineFutureFile" in arg else arg for arg in args]
                         error = None
                         try:
+                            print(args, kwargs)
                             exec_out = exec_function(*args, **kwargs)
                         except Exception as e:
                             exec_out = e
