@@ -97,17 +97,7 @@ class Manager(object):
         else:
             self._staging_explicit = None
 
-        # if we were given a range ports, rather than a single port to try.
-        lower, upper = None, None
-        try:
-            lower, upper = port
-            set_port_range(lower, upper)
-            port = 0
-        except TypeError:
-            # if not a range, ignore
-            pass
-        except ValueError:
-            raise ValueError("port should be a single integer, or a sequence of two integers")
+        set_port_range(port)
 
         if status_display_interval and status_display_interval >= 1:
             self._info_widget = JupyterDisplay(interval=status_display_interval)
@@ -125,13 +115,22 @@ class Manager(object):
             self._stats_hierarchy = cvine.vine_stats()
 
             ssl_key, ssl_cert = self._setup_ssl(ssl, run_info_path)
-            self._taskvine = cvine.vine_ssl_create(port, ssl_key, ssl_cert)
+
+            # use port = 0, as a port range has been set with set_port_range
+            self._taskvine = cvine.vine_ssl_create(0, ssl_key, ssl_cert)
 
             if ssl_key:
                 self._using_ssl = True
 
             if not self._taskvine:
-                raise Exception("Could not create manager on port {}".format(port))
+                msg = "Could not create manager on:"
+                msg += f"\nport: {port}"
+                if run_info_path:
+                    msg += f"\nrun_info_path: {os.path.abspath(run_info_path)}"
+                if staging_path:
+                    msg += f"\nstaging_path: {os.path.abspath(staging_path)}"
+
+                raise Exception(msg)
 
             if name:
                 cvine.vine_set_name(self._taskvine, name)
@@ -156,7 +155,7 @@ class Manager(object):
         try:
             if self._taskvine:
                 if self._shutdown:
-                    self.shutdown_workers(0)
+                    self.workers_shutdown(0)
                 self._update_status_display(force=True)
                 cvine.vine_delete(self._taskvine)
                 self._taskvine = None
@@ -481,11 +480,16 @@ class Manager(object):
     # Set the worker selection scheduler for manager.
     #
     # @param self       Reference to the current manager object.
-    # @param scheduler  One of the following schedulers to use in assigning a
-    #                   task to a worker. See @ref vine_schedule_t for
-    #                   possible values.
+    # @param scheduler  One of the following schedulers set preference when assigning a
+    #                   task to a worker:
+    #                     - "files"         Prefer the available worker that has the most data required for the task.
+    #                     - "time"          Prefer the available worker that has completed previous tasks the fastest.
+    #                     - "rand"          Select a random available worker.
+    #                     - "worst"         Select a worker with the most unused resources (tie breakers: cores, memory, disk).
+    #                     - "disk"          Select a worker with the most unused disk.
     def set_scheduler(self, scheduler):
-        return cvine.vine_set_scheduler(self._taskvine, scheduler)
+        sched = get_c_constant(f"schedule_{scheduler}")
+        return cvine.vine_set_scheduler(self._taskvine, sched)
 
     ##
     # Change the project name for the given manager.
@@ -847,7 +851,7 @@ class Manager(object):
     # - "max-retrievals" Sets the max number of tasks to retrieve per manager wait(). If less than 1, the manager prefers to retrieve all completed tasks before dispatching new tasks to workers. (default=1)
     # - "min-transfer-timeout" Set the minimum number of seconds to wait for files to be transferred to or from a worker. (default=10)
     # - "monitor-interval" Parameter to change how frequently the resource monitor records resource consumption of a task in a times series, if this feature is enabled. See @ref enable_monitoring.
-    # - "prefer-dispatch" If 1, try to dispatch tasks even if there are retrieved tasks ready to be reportedas done. (default=0)
+    # - "prefer-dispatch" If 1, try to dispatch tasks even if there are retrieved tasks ready to be reported as done. (default=0)
     # - "proportional-resources" If set to 0, do not assign resources proportionally to tasks. The default is to use proportions.
     # - "proportional-whole-tasks" Round up resource proportions such that only an integer number of tasks could be fit in the worker. The default is to use proportions.
     # - "ramp-down-heuristic" If set to 1 and there are more workers than tasks waiting, then tasks are allocated all the free resources of a worker large enough to run them. If monitoring watchdog is not enabled, then this heuristic has no effect. (default=0)
