@@ -11,6 +11,8 @@
 from . import cvine
 from .file import File
 
+from .utils import get_c_constant
+
 import copy
 import os
 import sys
@@ -186,10 +188,10 @@ class Task(object):
     ##
     # Return a copy of this task
     #
-    def clone(self):
+    def addref(self):
         """Return a (deep)copy this task that can also be submitted to the ndcctools.taskvine."""
         new = copy.copy(self)
-        new._task = cvine.vine_task_clone(self._task)
+        new._task = cvine.vine_task_addref(self._task)
         return new
 
     ##
@@ -292,11 +294,17 @@ class Task(object):
     # Set the worker selection scheduler for task.
     #
     # @param self       Reference to the current task object.
-    # @param scheduler  One of the following schedulers to use in assigning a
-    #                   task to a worker. See @ref vine_schedule_t for
-    #                   possible values.
+    # @param scheduler  One of the following schedulers set preference when assigning a
+    #                   task to a worker:
+    #                     - "files"         Prefer the available worker that has the most data required for the task.
+    #                     - "time"          Prefer the available worker that has completed previous tasks the fastest.
+    #                     - "rand"          Select a random available worker.
+    #                     - "worst"         Select a worker with the most unused resources (tie breakers: cores, memory, disk).
+    #                     - "disk"          Select a worker with the most unused disk.
+    #                   If not set for the task, defaults to the one set for the manager.
     def set_scheduler(self, scheduler):
-        return cvine.vine_task_set_scheduler(self._task, scheduler)
+        sched = get_c_constant(f"vine_schedule_{scheduler}")
+        return cvine.vine_task_set_scheduler(self._task, sched)
 
     ##
     # Attach a user defined logical name to the task.
@@ -1041,13 +1049,16 @@ class PythonTask(Task):
                                         except Exception as e:
                                             exec_out = e
                                             error = e
-                                        finally:
+                                        else:
                                             with open(out, "wb") as f:
                                                 if {serialize}:
                                                     cloudpickle.dump(exec_out, f)
                                                 else:
                                                     f.write(exec_out)
+                                        finally:
                                             if error:
+                                                import traceback
+                                                traceback.print_exc()
                                                 raise error
                                         """))
                 manager._function_buffers[base] = manager.declare_file(name, cache=True)
