@@ -102,7 +102,7 @@ struct vine_manager {
 	/* Primary data structures for tracking task state. */
 
 	struct itable *tasks;           /* Maps task_id -> vine_task of all tasks in any state. */
-	struct list   *ready_list;      /* List of vine_task that are waiting to execute. */
+	struct priority_queue   *ready_tasks;       /* Priority queue of vine_task that are waiting to execute. */
 	struct itable   *running_table;      /* Table of vine_task that are running at workers. */
 	struct list   *waiting_retrieval_list;      /* List of vine_task that are waiting to be retrieved. */
 	struct list   *retrieved_list;      /* List of vine_task that have been retrieved. */
@@ -116,8 +116,8 @@ struct vine_manager {
 	struct hash_table *worker_blocklist; /* Maps hostname -> vine_blocklist_info */
 	struct hash_table *factory_table;    /* Maps factory_name -> vine_factory_info */
 	struct hash_table *workers_with_watched_file_updates;  /* Maps link -> vine_worker_info */
-	struct hash_table *workers_with_complete_tasks;  /* Maps link -> vine_worker_info */
 	struct hash_table *current_transfer_table; 	/* Maps uuid -> struct transfer_pair */
+	struct itable     *task_group_table; 	/* Maps group id -> list vine_task */
 
 	/* Primary data structures for tracking files. */
 
@@ -136,7 +136,8 @@ struct vine_manager {
 	int next_task_id;       /* Next integer task_id to be assigned to a created task. */
 	int fixed_location_in_queue; /* Number of fixed location tasks currently being managed */
 	int num_tasks_left;    /* Optional: Number of tasks remaining, if given by user.  @ref vine_set_num_tasks */
-	int busy_waiting_flag; /* Set internally in main loop if no messages were processed -> wait longer. */
+	int nothing_happened_last_wait_cycle; /* Set internally in main loop if no messages or tasks were processed during the last wait loop.
+																					 If set, poll longer to avoid wasting cpu cycles, and growing log files unnecessarily.*/
 
 	/* Accumulation of statistics for reporting to the caller. */
 
@@ -181,6 +182,10 @@ struct vine_manager {
 	int tasks_waiting_last_hungry;     /* Number of tasks originally waiting when call to vine_hungry_computation was made. */
 	timestamp_t hungry_check_interval; /* Maximum interval between vine_hungry_computation checks. */
 
+	/* Task Groups Configuration */
+	int task_groups_enabled; 
+	int group_id_counter; 
+
 	/* Various performance knobs that can be tuned. */
 	int short_timeout;            /* Timeout in seconds to send/recv a brief message from worker */
 	int long_timeout;             /* Timeout if in the middle of an incomplete message. */
@@ -193,6 +198,7 @@ struct vine_manager {
 	int hungry_minimum;           /* Minimum number of waiting tasks to consider queue not hungry. */
 	int hungry_minimum_factor;    /* queue is hungry if number of waiting tasks is less than hungry_minimum_factor * number of connected workers. */
 	int wait_for_workers;         /* Wait for these many workers to connect before dispatching tasks at start of execution. */
+	int max_workers;              /* Specify the maximum number of workers to use during execution. */
 	int attempt_schedule_depth;   /* number of submitted tasks to attempt scheduling before we continue to retrievals */
 	int max_retrievals;           /* Do at most this number of task retrievals of either receive_one_task or receive_all_tasks_from_worker. If less
                                      than 1, prefer to receive all completed tasks before submitting new tasks. */
@@ -226,12 +232,16 @@ struct vine_manager {
 	double sandbox_grow_factor;         /* When task disk sandboxes are exhausted, increase the allocation using their measured valued times this factor */
 	double disk_proportion_available_to_task;   /* intentionally reduces disk allocation for tasks to reserve some space for cache growth. */
 
-	/*todo: confirm datatype. int or int64*/
+	/* todo: confirm datatype. int or int64 */
 	int max_task_stdout_storage;	/* Maximum size of standard output from task.  (If larger, send to a separate file.) */
 	int max_new_workers;			/* Maximum number of workers to add in a single cycle before dealing with other matters. */
 
 	timestamp_t large_task_check_interval;	/* How frequently to check for tasks that do not fit any worker. */
 	double option_blocklist_slow_workers_timeout;	/* Default timeout for slow workers to come back to the pool, can be set prior to creating a manager. */
+
+	/* Testing mode parameters */
+	timestamp_t enforce_worker_eviction_interval;   /* Enforce worker eviction interval in seconds */
+	timestamp_t time_start_worker_eviction;         /* Track the time when we start evicting workers */
 };
 
 /*
@@ -278,6 +288,9 @@ struct vine_task *vine_manager_no_wait(struct vine_manager *q, const char *tag,
 
 void vine_manager_remove_worker(struct vine_manager *q, struct vine_worker_info *w, vine_worker_disconnect_reason_t reason);
 
+/* Check if the worker is able to transfer the necessary files for this task. */
+int vine_manager_transfer_capacity_available(struct vine_manager *q, struct vine_worker_info *w, struct vine_task *t);
+
 /* The expected format of files created by the resource monitor.*/
 #define RESOURCE_MONITOR_TASK_LOCAL_NAME "vine-task-%d"
 #define RESOURCE_MONITOR_REMOTE_NAME "cctools-monitor"
