@@ -74,11 +74,14 @@ struct vine_task *vine_task_create(const char *command_line)
 	t->resources_measured = rmsummary_create(-1);
 	t->resources_allocated = rmsummary_create(-1);
 	t->current_resource_box = 0;
+	t->input_files_size = -1;
 
 	t->refcount = 1;
 	t->output_received = 0;
+	t->priority = 0;
 
 	vine_counters.task.created++;
+	t->group_id = 0;
 
 	return t;
 }
@@ -254,6 +257,11 @@ struct vine_task *vine_task_copy(const struct vine_task *task)
 		new->resources_requested = rmsummary_copy(task->resources_requested, 0);
 	}
 
+	/* Group ID is copied. */
+	if (task->group_id) {
+		new->group_id = task->group_id;
+	}
+
 	return new;
 }
 
