@@ -45,6 +45,9 @@ struct vine_worker_info *vine_worker_create(struct link *lnk)
 
 	vine_counters.worker.created++;
 
+	w->incoming_xfer_counter = 0;
+	w->outgoing_xfer_counter = 0;
+
 	return w;
 }
 
