@@ -93,6 +93,9 @@ struct vine_worker_info {
 	int xfer_total_bad_source_counter;
 	int xfer_total_good_destination_counter;
 	int xfer_total_bad_destination_counter;
+
+	int incoming_xfer_counter;
+	int outgoing_xfer_counter;
 };
 
 struct vine_worker_info * vine_worker_create( struct link * lnk );
