@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2008- The University of Notre Dame
+Copyright (C) 2022 The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -30,23 +30,28 @@ See the file COPYING for details.
 #define WORK_QUEUE_DEFAULT_KEEPALIVE_INTERVAL 120  /**< Default value for Work Queue keepalive interval in seconds. */
 #define WORK_QUEUE_DEFAULT_KEEPALIVE_TIMEOUT  30   /**< Default value for Work Queue keepalive timeout in seconds. */
 
+/** The input/output type of files used by @ref work_queue_task_specify_file and similar. */
+
 typedef enum {
 	WORK_QUEUE_INPUT  = 0,                         /**< Specify an input object. */
 	WORK_QUEUE_OUTPUT = 1                          /**< Specify an output object. */
 } work_queue_file_type_t;
 
+/** File handling flags used by @ref work_queue_task_specify_file and similar. */
+
 typedef enum {
 	WORK_QUEUE_NOCACHE  = 0, /**< Do not cache file at execution site. */
 	WORK_QUEUE_CACHE    = 1, /**< Cache file at execution site for later use. */
 	WORK_QUEUE_SYMLINK  = 2, /**< Create a symlink to the file rather than copying it, if possible. */
-	WORK_QUEUE_PREEXIST = 4, /**< If the filename already exists on the host, use it in place. */
-	WORK_QUEUE_THIRDGET = 8, /**< Access the file on the client from a shared filesystem */
-	WORK_QUEUE_THIRDPUT = 8, /**< Access the file on the client from a shared filesystem (same as WORK_QUEUE_THIRDGET, included for readability) */
 	WORK_QUEUE_WATCH    = 16, /**< Watch the output file and send back changes as the task runs. */
 	WORK_QUEUE_FAILURE_ONLY = 32,/**< Only return this output file if the task failed.  (Useful for returning large log files.) */
-	WORK_QUEUE_SUCCESS_ONLY = 64 /**< Only return this output file if the task succeeded. */
+	WORK_QUEUE_SUCCESS_ONLY = 64, /**< Only return this output file if the task succeeded. */
+
+	WORK_QUEUE_PREEXIST = 4 /**< If the filename already exists on the host, use it in place. (Warning: Internal work queue use only.) */
 } work_queue_file_flags_t;
 
+/** Task scheduling modes used by @ref work_queue_specify_algorithm and @ref work_queue_task_specify_algorithm. */
+
 typedef enum {
 	WORK_QUEUE_SCHEDULE_UNSET = 0,
 	WORK_QUEUE_SCHEDULE_FCFS,      /**< Select worker on a first-come-first-serve basis. */
@@ -56,6 +61,7 @@ typedef enum {
 	WORK_QUEUE_SCHEDULE_WORST      /**< Select the worst fit worker (the worker with more unused resources). */
 } work_queue_schedule_t;
 
+/** Task result types set when a task is complete. */
 
 typedef enum {
 	WORK_QUEUE_RESULT_SUCCESS             = 0,      /**< The task ran successfully **/
@@ -70,9 +76,12 @@ typedef enum {
 	WORK_QUEUE_RESULT_MAX_RETRIES         = 6 << 3, /**< The task could not be completed successfully in the given number of retries. **/
 	WORK_QUEUE_RESULT_TASK_MAX_RUN_TIME   = 7 << 3, /**< The task ran for more than the specified time (relative since running in a worker). **/
 	WORK_QUEUE_RESULT_DISK_ALLOC_FULL     = 8 << 3, /**< The task filled its loop device allocation but needed more space. **/
-	WORK_QUEUE_RESULT_RMONITOR_ERROR      = 9 << 3  /**< The task failed because the monitor did not produce a summary report. **/
+	WORK_QUEUE_RESULT_RMONITOR_ERROR      = 9 << 3, /**< The task failed because the monitor did not produce a summary report. **/
+	WORK_QUEUE_RESULT_OUTPUT_TRANSFER_ERROR = 10 << 3  /**< The task failed because an output could be transfered to the manager (not enough disk space, incorrect write permissions. */
 } work_queue_result_t;
 
+/** State of a task throughout its lifetime. */
+
 typedef enum {
 	WORK_QUEUE_TASK_UNKNOWN = 0,       /**< There is no such task **/
 	WORK_QUEUE_TASK_READY,             /**< Task is ready to be run, waiting in queue **/
@@ -83,6 +92,8 @@ typedef enum {
 	WORK_QUEUE_TASK_CANCELED,           /**< Task was canceled before completion **/
 } work_queue_task_state_t;
 
+/** Types of files that can be attached to a task. */
+
 typedef enum {
 	WORK_QUEUE_FILE = 1,              /**< File-spec is a regular file **/
 	WORK_QUEUE_BUFFER,                /**< Data comes from buffer memory **/
@@ -93,39 +104,29 @@ typedef enum {
 } work_queue_file_t;
 
 
-/** Here we repeat the category_mode_t declaration but with work_queue names.
- * This is needed to generate uniform names in the API and bindings. */
-enum {
-    WORK_QUEUE_ALLOCATION_MODE_FIXED          = CATEGORY_ALLOCATION_MODE_FIXED,
-    WORK_QUEUE_ALLOCATION_MODE_MAX            = CATEGORY_ALLOCATION_MODE_MAX,
-    WORK_QUEUE_ALLOCATION_MODE_MIN_WASTE      = CATEGORY_ALLOCATION_MODE_MIN_WASTE,
-    WORK_QUEUE_ALLOCATION_MODE_MAX_THROUGHPUT = CATEGORY_ALLOCATION_MODE_MAX_THROUGHPUT
-};
+// Here we repeat the category_mode_t declaration but with work_queue names.
+// This is needed to generate uniform names in the API and bindings:
 
-// typedef enum {
-// /**< When monitoring is disabled, all tasks run as
-//   WORK_QUEUE_ALLOCATION_MODE_FIXED. If monitoring is enabled and resource
-//   exhaustion occurs: */
-// 	WORK_QUEUE_ALLOCATION_MODE_FIXED = 0,   /**< Task fails. (default) */
-// 	WORK_QUEUE_ALLOCATION_MODE_MAX,         /**< If maximum values are specified for cores, memory,
-// 											  disk or gpus (either a user-label or category-label) and
-// 											  one of those resources is exceeded, the task fails.
-// 											  Otherwise it is retried until a large enough worker
-// 											  connects to the manager, using the maximum values
-// 											  specified, and the maximum values so far seen for
-// 											  resources not specified. */
-// 
-// 	WORK_QUEUE_ALLOCATION_MODE_MIN_WASTE,   /**< As above, but tasks are tried with an automatically
-// 											  computed first-allocation to minimize resource waste. */
-// 	WORK_QUEUE_ALLOCATION_MODE_MAX_THROUGHPUT /**< As above, but maximizing throughput. */
-// } wq_category_mode_t;
+typedef enum {
+    WORK_QUEUE_ALLOCATION_MODE_FIXED          = CATEGORY_ALLOCATION_MODE_FIXED, /**< When monitoring is disabled, all tasks run as
+                                                                                  WORK_QUEUE_ALLOCATION_MODE_FIXED. If monitoring is enabled and resource
+                                                                                  exhaustion occurs for specified resources values, then the task permanently fails. */
+    WORK_QUEUE_ALLOCATION_MODE_MAX            = CATEGORY_ALLOCATION_MODE_MAX, /**< When monitoring is enabled, tasks are tried with maximum specified values
+                                                                                of cores, memory, disk or gpus until enough statistics are collected. Then,
+                                                                                further tasks are first tried using the maximum values observed, and in case of
+                                                                                resource exhaustion, they are retried using the maximum specified values. The
+                                                                                task permanently fails when there is an exhaustion using the maximum values. If
+                                                                                no maximum values are specified, the task will wait until a larger worker
+                                                                                connects. */
+    WORK_QUEUE_ALLOCATION_MODE_MIN_WASTE      = CATEGORY_ALLOCATION_MODE_MIN_WASTE, /**< As above, but tasks are first tried with an automatically
+                                                                                      computed allocation to minimize resource waste. */
+    WORK_QUEUE_ALLOCATION_MODE_MAX_THROUGHPUT = CATEGORY_ALLOCATION_MODE_MAX_THROUGHPUT, /**< As above, but maximizing throughput. */
+    
+    WORK_QUEUE_ALLOCATION_MODE_GREEDY_BUCKETING = CATEGORY_ALLOCATION_MODE_GREEDY_BUCKETING, /**< Use the greedy bucketing algorithm to label resources */
 
+    WORK_QUEUE_ALLOCATION_MODE_EXHAUSTIVE_BUCKETING = CATEGORY_ALLOCATION_MODE_EXHAUSTIVE_BUCKETING /**< Use the exhaustive bucketing algorithm to label resources */
+} work_queue_category_mode_t;
 
-extern int wq_option_scheduler;	               /**< Initial setting for algorithm to assign tasks to
-												 workers upon creating queue . Change prior to
-												 calling work_queue_create, after queue is created
-												 this variable is not considered and changes must be
-												 made through the API calls.   */
 
 /** A task description.  This structure should only be created with @ref
  * work_queue_task_create and delete with @ref work_queue_task_delete.  You may
@@ -145,6 +146,8 @@ struct work_queue_task {
 	char *host;                                       /**< The address and port of the host on which it ran. */
 	char *hostname;                                   /**< The name of the host on which it ran. */
 
+	char *coprocess;                                  /**< The name of the coprocess name in the worker that executes this task. For regular tasks it is NULL. */
+
 	char *category;                         /**< User-provided label for the task. It is expected that all task with the same category will have similar resource usage. See @ref work_queue_task_specify_category. If no explicit category is given, the label "default" is used. **/
 	category_allocation_t resource_request; /**< See @ref category_allocation_t */
 
@@ -153,6 +156,7 @@ struct work_queue_task {
 
 	int try_count;          /**< The number of times the task has been dispatched to a worker. If larger than max_retries, the task failes with @ref WORK_QUEUE_RESULT_MAX_RETRIES. */
 	int exhausted_attempts; /**< Number of times the task failed given exhausted resources. */
+	int fast_abort_count; /**< Number of times this task has been terminated for running too long. */
 
 	/* All times in microseconds */
 	/* A time_when_* refers to an instant in time, otherwise it refers to a length of time. */
@@ -161,6 +165,9 @@ struct work_queue_task {
 
 	int disk_allocation_exhausted;                        /**< Non-zero if a task filled its loop device allocation, zero otherwise. */
 
+	int64_t min_running_time;           /**< Minimum time (in seconds) the task needs to run. (see work_queue_worker --wall-time)*/
+
+    /**< All fields of the form time_* in microseconds. */
 	timestamp_t time_when_commit_start; /**< The time when the task starts to be transfered to a worker. */
 	timestamp_t time_when_commit_end;   /**< The time when the task is completely transfered to a worker. */
 
@@ -332,8 +339,8 @@ struct work_queue_stats {
 
 	double capacity; /**< @deprecated Use capacity_cores. */
 
-	double efficiency;      /**< @deprecated. broken. */
-	double idle_percentage; /**< @deprecated. */
+	double efficiency;      /**< @deprecated broken. */
+	double idle_percentage; /**< @deprecated */
 
 	int64_t total_gpus;       /**< @deprecated: broken. */
 	int64_t committed_gpus;   /**< @deprecated: broken. */
@@ -349,6 +356,7 @@ struct work_queue_stats {
 	int workers_blacklisted;         /**< @deprecated Use workers_blocked instead. */
 };
 
+
 /* Forward declare the queue's structure. This structure is opaque and defined in work_queue.c */
 struct work_queue;
 
@@ -360,8 +368,9 @@ struct work_queue;
 /** Create a new task object.
 Once created and elaborated with functions such as @ref work_queue_task_specify_file
 and @ref work_queue_task_specify_buffer, the task should be passed to @ref work_queue_submit.
-@param full_command The shell command line to be executed by the task.  If null,
-the command will be given later by @ref work_queue_task_specify_command
+@param full_command The shell command line or coprocess functions to be
+executed by the task.  If null, the command will be given later by @ref
+work_queue_task_specify_command
 @return A new task object, or null if it could not be created.
 */
 struct work_queue_task *work_queue_task_create(const char *full_command);
@@ -379,6 +388,13 @@ struct work_queue_task *work_queue_task_clone(const struct work_queue_task *task
 */
 void work_queue_task_specify_command( struct work_queue_task *t, const char *cmd );
 
+/** Indicate the command to be executed.
+@param t A task object.
+@param coprocess_name The coprocess name that will execute the command at the worker. The task
+will only be sent to workers running the coprocess.
+*/
+void work_queue_task_specify_coprocess( struct work_queue_task *t, const char *coprocess_name );
+
 /** Add a file to a task.
 @param t A task object.
 @param local_name The name of the file on local disk or shared filesystem.
@@ -440,10 +456,24 @@ int work_queue_task_specify_buffer(struct work_queue_task *t, const char *data,
 */
 int work_queue_task_specify_directory(struct work_queue_task *t, const char *local_name, const char *remote_name, work_queue_file_type_t type, work_queue_file_flags_t flags, int recursive);
 
+/** Add a url as an input for a task.
+@param t A task object.
+@param url The source URL to be accessed to provide the file.
+@param remote_name The name of the file as seen by the task.
+@param type Must be one of the following values:
+- @ref WORK_QUEUE_INPUT to indicate an input file to be consumed by the task
+- @ref WORK_QUEUE_OUTPUT is not currently supported.
+@param flags	May be zero to indicate no special handling or any of @ref work_queue_file_flags_t or'd together. The most common are:
+- @ref WORK_QUEUE_CACHE indicates that the file should be cached for later tasks. (recommended)
+- @ref WORK_QUEUE_NOCACHE indicates that the file should not be cached for later tasks.
+@return 1 if the task file is successfully specified, 0 if either of @a t or @a remote_name is null or @a remote_name is an absolute path.
+*/
+int work_queue_task_specify_url(struct work_queue_task *t, const char *url, const char *remote_name, work_queue_file_type_t type, work_queue_file_flags_t flags);
+
 /** Gets/puts file at remote_name using cmd at worker.
 @param t A task object.
-@param remote_name The name of the file as seen by the task.
 @param cmd The shell command to transfer the file. For input files, it should read the contents from remote_name via stdin. For output files, it should write the contents to stdout.
+@param remote_name The name of the file as seen by the task.
 @param type Must be one of the following values:
 - @ref WORK_QUEUE_INPUT to indicate an input file to be consumed by the task
 - @ref WORK_QUEUE_OUTPUT to indicate an output file to be produced by the task
@@ -452,7 +482,7 @@ int work_queue_task_specify_directory(struct work_queue_task *t, const char *loc
 - @ref WORK_QUEUE_NOCACHE indicates that the file should not be cached for later tasks.
 @return 1 if the task file is successfully specified, 0 if either of @a t or @a remote_name is null or @a remote_name is an absolute path.
 */
-int work_queue_task_specify_file_command(struct work_queue_task *t, const char *remote_name, const char *cmd, work_queue_file_type_t type, work_queue_file_flags_t flags);
+int work_queue_task_specify_file_command(struct work_queue_task *t, const char *cmd, const char *remote_name, work_queue_file_type_t type, work_queue_file_flags_t flags);
 
 /** Specify the number of times this task is retried on worker errors. If less than one, the task is retried indefinitely (this the default). A task that did not succeed after the given number of retries is returned with result WORK_QUEUE_RESULT_MAX_RETRIES.
 @param t A task object.
@@ -498,6 +528,14 @@ This is useful, for example, when the task uses certificates that expire.
 
 void work_queue_task_specify_end_time( struct work_queue_task *t, int64_t useconds );
 
+/** Specify the minimum start time allowed for the task (in microseconds since the
+ * Epoch). If less than 1, then no minimum start time is specified (this is the default).
+@param t A task object.
+@param useconds Number of useconds since the Epoch.
+*/
+
+void work_queue_task_specify_start_time_min( struct work_queue_task *t, int64_t useconds );
+
 /** Specify the maximum time (in microseconds) the task is allowed to run in a
  * worker. This time is accounted since the the moment the task starts to run
  * in a worker.  If less than 1, then no maximum time is specified (this is the default).
@@ -507,6 +545,23 @@ void work_queue_task_specify_end_time( struct work_queue_task *t, int64_t usecon
 
 void work_queue_task_specify_running_time( struct work_queue_task *t, int64_t useconds );
 
+/** Specify the maximum time (in seconds) the task is allowed to run in a worker.
+ * This time is accounted since the moment the task starts to run in a worker.
+ * If less than 1, then no maximum time is specified (this is the default).
+ * Note: same effect as work_queue_task_specify_running_time.
+@param t A task object.
+@param seconds Maximum number of seconds the task may run in a worker.
+*/
+void work_queue_task_specify_running_time_max( struct work_queue_task *t, int64_t seconds );
+
+/** Specify the minimum time (in seconds) the task is expected to run in a worker.
+ * This time is accounted since the moment the task starts to run in a worker.
+ * If less than 1, then no minimum time is specified (this is the default).
+@param t A task object.
+@param seconds Minimum number of seconds the task may run in a worker.
+*/
+void work_queue_task_specify_running_time_min( struct work_queue_task *t, int64_t seconds );
+
 /** Attach a user defined string tag to the task.
 This field is not interpreted by the work queue, but is provided for the user's convenience
 in identifying tasks when they complete.
@@ -642,6 +697,17 @@ the <b>CATALOG_HOST</b> and <b>CATALOG_PORT</b> environmental variables as descr
 */
 struct work_queue *work_queue_create(int port);
 
+
+/** Create a new work queue using SSL.
+ Like @ref work_queue_create, but all communications with the queue are encoded
+ using TLS with they key and certificate provided. If key or cert are NULL,
+ then TLS is not activated.
+@param port The port number to listen on.  If zero is specified, then the port stored in the <b>WORK_QUEUE_PORT</b> environment variable is used if available. If it isn't, or if -1 is specified, the first unused port between <b>WORK_QUEUE_LOW_PORT</b> and <b>WORK_QUEUE_HIGH_PORT</b> (1024 and 32767 by default) is chosen.
+@param key A key in pem format.
+@param cert A certificate in pem format.
+*/
+struct work_queue *work_queue_ssl_create(int port, const char *key, const char *cert);
+
 /** Enables resource monitoring on the give work queue.
 It generates a resource summary per task, which is written to the given
 directory. It also creates all_summaries-PID.log, that consolidates all
@@ -750,6 +816,16 @@ If the task could not, then the <tt>result</tt> field will be non-zero and the
 */
 struct work_queue_task *work_queue_wait(struct work_queue *q, int timeout);
 
+
+/** Wait for a task with a given task to complete.
+Similar to @ref work_queue_wait, but guarantees that the returned task has the specified tag.
+@param q A work queue object.
+@param tag The desired tag. If NULL, then tasks are returned regardless of their tag.
+@param timeout The number of seconds to wait for a completed task before returning.  Use an integer time to set the timeout or the constant @ref WORK_QUEUE_WAITFORTASK to block until a task has completed.
+@returns A completed task description, or null if the queue is empty, or the timeout was reached without a completed task, or there is completed child process (call @ref process_wait to retrieve the status of the completed child process).
+*/
+struct work_queue_task *work_queue_wait_for_tag(struct work_queue *q, const char *tag, int timeout);
+
 /** Determine whether the queue is 'hungry' for more tasks.
 While the Work Queue can handle a very large number of tasks,
 it runs most efficiently when the number of tasks is slightly
@@ -799,6 +875,18 @@ void work_queue_get_stats_hierarchy(struct work_queue *q, struct work_queue_stat
 */
 void work_queue_get_stats_category(struct work_queue *q, const char *c, struct work_queue_stats *s);
 
+/** Get queue information as json
+@param q A work queue object.
+@param request One of: queue, tasks, workers, or categories
+*/
+char *work_queue_status(struct work_queue *q, const char *request);
+
+
+/** Summary data for all workers in buffer.
+@param q A work queue object.
+@return A null terminated array of struct rmsummary. Each summary s indicates the number of s->workers with a certain number of s->cores, s->memory, and s->disk. The array and summaries need to be freed after use to avoid memory leaks.
+*/
+struct rmsummary **work_queue_workers_summary(struct work_queue *q);
 
 /** Get the current state of the task.
 @param q A work queue object.
@@ -864,10 +952,17 @@ int work_queue_specify_draining_by_hostname(struct work_queue *q, const char *ho
 /** Turn on or off first-allocation labeling for a given category. By default, cores, memory, and disk are labeled, and gpus are unlabeled. Turn on/off other specific resources use @ref work_queue_enable_category_resource
 @param q A work queue object.
 @param category A category name.
-@param mode     One of @ref category_mode_t.
+@param mode     One of @ref work_queue_category_mode_t.
 @returns 1 if mode is valid, 0 otherwise.
 */
-int work_queue_specify_category_mode(struct work_queue *q, const char *category, category_mode_t mode);
+int work_queue_specify_category_mode(struct work_queue *q, const char *category, work_queue_category_mode_t mode);
+
+/** Set a maximum number of tasks of this category that can execute concurrently. If less than 0, unlimited (this is the default).
+@param q A work queue object.
+@param category A category name.
+@param max_concurrent Number of maximum concurrent tasks.
+*/
+void work_queue_specify_category_max_concurrent(struct work_queue *q, const char *category, int max_concurrent);
 
 /** Turn on or off first-allocation labeling for a given category and resource. This function should be use to fine-tune the defaults from @ref work_queue_specify_category_mode.
 @param q A work queue object.
@@ -1012,7 +1107,7 @@ void work_queue_specify_keepalive_interval(struct work_queue *q, int interval);
 void work_queue_specify_keepalive_timeout(struct work_queue *q, int timeout);
 
 /** Set the preference for using hostname over IP address to connect.
-'by_ip' uses IP address (standard behavior), or 'by_hostname' to use the hostname at the manager.
+'by_ip' uses IP addresses from the network interfaces of the manager (standard behavior), 'by_hostname' to use the hostname at the manager, or 'by_apparent_ip' to use the address of the manager as seen by the catalog server.
 @param q A work queue object.
 @param preferred_connection An string to indicate using 'by_ip' or a 'by_hostname'.
 */
@@ -1021,8 +1116,7 @@ void work_queue_manager_preferred_connection(struct work_queue *q, const char *p
 /** Tune advanced parameters for work queue.
 @param q A work queue object.
 @param name The name of the parameter to tune
- - "asynchrony-multiplier" Treat each worker as having (actual_cores * multiplier) total cores. (default = 1.0)
- - "asynchrony-modifier" Treat each worker as having an additional "modifier" cores. (default=0)
+ - "resource-submit-multiplier" Treat each worker as having ({cores,memory,gpus} * multiplier) when submitting tasks. This allows for tasks to wait at a worker rather than the manager. (default = 1.0)
  - "min-transfer-timeout" Set the minimum number of seconds to wait for files to be transferred to or from a worker. (default=10)
  - "foreman-transfer-timeout" Set the minimum number of seconds to wait for files to be transferred to or from a foreman. (default=3600)
  - "transfer-outlier-factor" Transfer that are this many times slower than the average will be aborted.  (default=10x)
@@ -1033,6 +1127,11 @@ void work_queue_manager_preferred_connection(struct work_queue *q, const char *p
  - "short-timeout" Set the minimum timeout when sending a brief message to a single worker. (default=5s)
  - "long-timeout" Set the minimum timeout when sending a brief message to a foreman. (default=1h)
  - "category-steady-n-tasks" Set the number of tasks considered when computing category buckets.
+ - "hungry-minimum" Mimimum number of tasks to consider queue not hungry. (default=10)
+ - "wait-for-workers" Mimimum number of workers to connect before starting dispatching tasks. (default=0)
+ - "attempt-schedule-depth" The amount of tasks to attempt scheduling on each pass of send_one_task in the main loop. (default=100)
+ - "wait_retrieve_many" Parameter to alter how work_queue_wait works. If set to 0, work_queue_wait breaks out of the while loop whenever a task changes to WORK_QUEUE_TASK_DONE (wait_retrieve_one mode). If set to 1, work_queue_wait does not break, but continues recieving and dispatching tasks. This occurs until no task is sent or recieved, at which case it breaks out of the while loop (wait_retrieve_many mode). (default=0)
+ - "monitor-interval" Parameter to change how frequently the resource monitor records resource consumption of a task in a times series, if this feature is enabled. See @ref work_queue_enable_monitoring_full.
 @param value The value to set the parameter to.
 @return 0 on succes, -1 on failure.
 */
@@ -1081,6 +1180,12 @@ void work_queue_specify_category_first_allocation_guess(struct work_queue *q,  c
 void work_queue_initialize_categories(struct work_queue *q, struct rmsummary *max, const char *summaries_file);
 
 
+/** Explain result codes from tasks.
+@param result Result from a task returned by @ref work_queue_wait.
+@return String representation of task result code.
+*/
+const char *work_queue_result_str(work_queue_result_t result);
+
 //@}
 
 /** @name Functions - Deprecated */
