@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2008- The University of Notre Dame
+Copyright (C) 2022 The University of Notre Dame
 This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
@@ -20,16 +20,15 @@ This file should not be installed and should only be included by .c files.
 /* 7: added category message */
 /* 8: worker send feature message. */
 /* 9: recursive send/recv and filename encoding. */
-#define WORK_QUEUE_PROTOCOL_VERSION 9
+/* 10: added coprocess message. */
+/* 11: added url/command as a file source, added cache-update/invalidate */
+
+#define WORK_QUEUE_PROTOCOL_VERSION 11
 
 #define WORK_QUEUE_LINE_MAX 4096       /**< Maximum length of a work queue message line. */
 #define WORK_QUEUE_POOL_NAME_MAX 128   /**< Maximum length of a work queue pool name. */
 #define WORKER_WORKSPACE_NAME_MAX 2048   /**< Maximum length of a work queue worker's workspace name. */
 
-#define WORK_QUEUE_FS_CMD 1            /**< Indicates thirdput/thirdget should execute a command. */
-#define WORK_QUEUE_FS_PATH 2           /**< Indicates thirdput/thirdget refers to a path. */
-#define WORK_QUEUE_FS_SYMLINK 3        /**< Indicates thirdput/thirdget should create a symlink. */
-
 #define WORK_QUEUE_PROTOCOL_FIELD_MAX 256
 
 #endif
